@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: commands.c,v 1.30 2006/09/08 15:32:57 smorlat Exp $
+ *  $Id: commands.c,v 1.31 2006/09/22 07:22:47 smorlat Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2004  Simon MORLAT <simon.morlat@linphone.org>
@@ -52,6 +52,8 @@ static int lpc_cmd_ipv6(LinphoneCore *, char *);
 static int lpc_cmd_refer(LinphoneCore *, char *);
 static int lpc_cmd_quit(LinphoneCore *, char *);
 static int lpc_cmd_nat(LinphoneCore *, char *);
+static int lpc_cmd_stun(LinphoneCore *, char *);
+static int lpc_cmd_firewall(LinphoneCore *, char *);
 static int lpc_cmd_friend(LinphoneCore *, char*);
 static int lpc_cmd_soundcard(LinphoneCore *, char *);
 static int lpc_cmd_play(LinphoneCore *, char *);
@@ -115,8 +117,16 @@ LPC_COMMAND commands[] = {
 	{ "nat", lpc_cmd_nat, "Set nat address",
 		"'nat'        : show nat settings.\n"
 		"'nat <addr>' : set nat address (and enable its use).\n"
-		"'nat use'    : enable nat use (ip must be set).\n"
-		"'nat unuse'  : disable nat use.\n"
+	},
+	{ "stun", lpc_cmd_stun, "Set stun server address",
+		"'stun'        : show stun settings.\n"
+		"'stun <addr>' : set stun address (and enable its use).\n"
+	},
+	{ "firewall", lpc_cmd_firewall, "Set ",
+		"'firewall'        : show current firewall policy.\n"
+		"'firewall none' : use direct connection.\n"
+		"'firewall nat' : use nat address given with the 'nat' command.\n"
+		"'firewall stun' : use stun server given with the 'server' command.\n"
 	},
         { "call-logs", lpc_cmd_call_logs, "Calls history",
                 NULL },
@@ -339,28 +349,66 @@ lpc_cmd_nat(LinphoneCore *lc, char *args)
 
 	if ( args && *args )
 	{
-		if ( ! strncmp(args, "use", 3) )
-		{
-			linphone_core_use_nat_address(lc,TRUE);
-		}
-		else if ( ! strncmp(args, "unuse", 5) )
-		{
-			linphone_core_use_nat_address(lc,FALSE);
-		}
-		else
-		{
-			linphone_core_set_nat_address(lc, args);
-			linphone_core_use_nat_address(lc,TRUE);
-		}
+		linphone_core_set_nat_address(lc, args);
+		linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_NAT_ADDRESS);
 	}
 
 	nat = linphone_core_get_nat_address(lc);
-	use = linphone_core_nat_address_used(lc);
+	use = linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_NAT_ADDRESS;
 	printf("Nat address: %s%s\n", nat, use?"":" (unused)");
 
 	return 1;
 }
 
+static int
+lpc_cmd_stun(LinphoneCore *lc, char *args)
+{
+	bool_t use;
+	const char *nat;
+
+	if ( args ) args=lpc_strip_blanks(args);
+
+	if ( args && *args )
+	{
+		linphone_core_set_stun_server(lc, args);
+		linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_STUN);
+	}
+
+	nat = linphone_core_get_stun_server(lc);
+	use = linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_STUN;
+	printf("Stun server: %s%s\n", nat, use?"":" (unused)");
+
+	return 1;
+}
+
+static int
+lpc_cmd_firewall(LinphoneCore *lc, char *args)
+{
+	if ( args ) args=lpc_strip_blanks(args);
+
+	if ( args && *args )
+	{
+		if (strcmp(args,"none")==0)
+			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_NO_FIREWALL);
+		else if (strcmp(args,"stun")==0)
+			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_STUN);
+		else if (strcmp(args,"nat")==0)
+			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_USE_NAT_ADDRESS);
+	}
+	switch(linphone_core_get_firewall_policy(lc)){
+		case LINPHONE_POLICY_NO_FIREWALL:
+			printf("No firewall\n");
+			break;
+		case LINPHONE_POLICY_USE_STUN:
+			printf("Using stun server to discover firewall address\n");
+			break;
+		case LINPHONE_POLICY_USE_NAT_ADDRESS:
+			printf("Using supplied nat address.\n");
+			break;
+	}
+	return 1;
+}
+
 static int
 lpc_cmd_friend(LinphoneCore *lc, char *args)
 {
@@ -798,7 +846,7 @@ linphonec_proxy_display(LinphoneProxyConfig *cfg)
 static void
 linphonec_proxy_list(LinphoneCore *lc)
 {
-	MSList *proxies;
+	const MSList *proxies;
 	int n;
 	int def=linphone_core_get_default_proxy(lc,NULL);
 	
@@ -815,7 +863,7 @@ linphonec_proxy_list(LinphoneCore *lc)
 static void
 linphonec_proxy_remove(LinphoneCore *lc, int index)
 {
-	MSList *proxies;
+	const MSList *proxies;
 	LinphoneProxyConfig *cfg;
 	proxies=linphone_core_get_proxy_config_list(lc);
 	cfg=(LinphoneProxyConfig*)ms_list_nth_data(proxies,index);
@@ -831,7 +879,7 @@ linphonec_proxy_remove(LinphoneCore *lc, int index)
 static int
 linphonec_proxy_use(LinphoneCore *lc, int index)
 {
-	MSList *proxies;
+	const MSList *proxies;
 	LinphoneProxyConfig *cfg;
 	proxies=linphone_core_get_proxy_config_list(lc);
 	cfg=(LinphoneProxyConfig*)ms_list_nth_data(proxies,index);
@@ -932,6 +980,9 @@ lpc_find_command(const char *name)
 /****************************************************************************
  *
  * $Log: commands.c,v $
+ * Revision 1.31  2006/09/22 07:22:47  smorlat
+ * linphonecore api changes.
+ *
  * Revision 1.30  2006/09/08 15:32:57  smorlat
  * support for using files instead of soundcard (used by linphonec only)
  *
