@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: linphonec.c,v 1.46 2006/03/16 17:17:40 smorlat Exp $
+ *  $Id: linphonec.c,v 1.51 2006/08/21 12:49:59 smorlat Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2002  Florian Winterstein <flox@gmx.net>
@@ -33,7 +33,19 @@
 #include <limits.h>
 #include <linphonecore.h>
 #include "linphonec.h"
-#include "../config.h"
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_GETTEXT
+#include <libintl.h>
+#ifndef _
+#define _(String) gettext(String)
+#endif
+#else
+#define _(something)	(something)
+#endif
 
 /***************************************************************************
  *
@@ -69,9 +81,9 @@ static char **linephonec_readline_completion(const char *text,
 static void linphonec_call_received(LinphoneCore *lc, const char *from);
 static void linphonec_prompt_for_auth(LinphoneCore *lc, const char *realm,
 	const char *username);
-static void linphonec_display_something (LinphoneCore * lc, char *something);
-static void linphonec_display_url (LinphoneCore * lc, char *something, char *url);
-static void linphonec_display_warning (LinphoneCore * lc, char *something);
+static void linphonec_display_something (LinphoneCore * lc, const char *something);
+static void linphonec_display_url (LinphoneCore * lc, const char *something, const char *url);
+static void linphonec_display_warning (LinphoneCore * lc, const char *something);
 static void stub () {}
 static void linphonec_notify_received(LinphoneCore *lc,LinphoneFriend *fid,
 		const char *from, const char *status, const char *img);
@@ -80,7 +92,7 @@ static void linphonec_new_unknown_subscriber(LinphoneCore *lc,
 static void linphonec_bye_received(LinphoneCore *lc, const char *from);
 static void linphonec_text_received(LinphoneCore *lc, LinphoneChatRoom *cr,
 		const char *from, const char *msg);
-static void linphonec_display_status (LinphoneCore * lc, char *something);
+static void linphonec_display_status (LinphoneCore * lc, const char *something);
 
 /***************************************************************************
  *
@@ -91,9 +103,10 @@ static void linphonec_display_status (LinphoneCore * lc, char *something);
 LinphoneCore linphonec;
 FILE *mylogfile;
 static char *histfile_name=NULL;
-static char *last_in_history=NULL;
+static char last_in_history[256];
 //auto answer (-a) option
-static gboolean auto_answer=FALSE;
+static bool_t auto_answer=FALSE;
+static bool_t answer_call=FALSE;
 LPC_AUTH_STACK auth_stack;
 static int trace_level = 0;
 static char *logfile_name = NULL;
@@ -130,7 +143,7 @@ LinphoneCoreVTable linphonec_vtable = {
  * Linphone core callback 
  */
 static void
-linphonec_display_something (LinphoneCore * lc, char *something)
+linphonec_display_something (LinphoneCore * lc, const char *something)
 {
 	fprintf (stdout, "%s\n", something);
 }
@@ -139,7 +152,7 @@ linphonec_display_something (LinphoneCore * lc, char *something)
  * Linphone core callback 
  */
 static void
-linphonec_display_status (LinphoneCore * lc, char *something)
+linphonec_display_status (LinphoneCore * lc, const char *something)
 {
 	fprintf (stdout, "%s\n", something);
 }
@@ -148,7 +161,7 @@ linphonec_display_status (LinphoneCore * lc, char *something)
  * Linphone core callback 
  */
 static void
-linphonec_display_warning (LinphoneCore * lc, char *something)
+linphonec_display_warning (LinphoneCore * lc, const char *something)
 {
 	fprintf (stdout, "Warning: %s\n", something);
 }
@@ -157,7 +170,7 @@ linphonec_display_warning (LinphoneCore * lc, char *something)
  * Linphone core callback 
  */
 static void
-linphonec_display_url (LinphoneCore * lc, char *something, char *url)
+linphonec_display_url (LinphoneCore * lc, const char *something, const char *url)
 {
 	fprintf (stdout, "%s : %s\n", something, url);
 }
@@ -170,8 +183,7 @@ static void
 linphonec_call_received(LinphoneCore *lc, const char *from)
 {
 	if ( auto_answer)  {
-		fprintf (stdout, "-------auto answering to call-------\n" );
-		linphone_core_accept_call(lc,NULL);
+		answer_call=TRUE;
 	}
 }
 
@@ -505,7 +517,11 @@ linphonec_idle_call ()
 	/* printf(".\n"); */
 
 	linphone_core_iterate(opm);
-
+	if (answer_call){
+		fprintf (stdout, "-------auto answering to call-------\n" );
+		linphone_core_accept_call(opm,NULL);
+		answer_call=FALSE;
+	}
 
 #if 0 /* Automatic exit should be requested with a command line switch */
 	/* Quit if autocall mode was on and no call is in progress */
@@ -548,12 +564,11 @@ linphonec_initialize_readline()
 	rl_event_hook=linphonec_idle_call;
 
 	/* Set history file and read it */
-	histfile_name = g_strdup_printf ("%s/.linphonec_history",
+	histfile_name = ms_strdup_printf ("%s/.linphonec_history",
 		getenv("HOME"));
 	read_history(histfile_name);
 
-	/* Initialized last_in_history cache */
-	last_in_history = malloc(256);
+	/* Initialized last_in_history cache*/
 	last_in_history[0] = '\0';
 
 	/* Register a completion function */
@@ -574,7 +589,6 @@ linphonec_initialize_readline()
 static int
 linphonec_finish_readline()
 {
-	free(last_in_history);
 
 	stifle_history(HISTSIZE);
 	write_history(histfile_name);
@@ -587,7 +601,7 @@ static int
 linphonec_main_loop (LinphoneCore * opm, char * sipAddr)
 {
 	char buf[LINE_MAX_LEN]; /* auto call handling */
-	gboolean run=TRUE;
+	bool_t run=TRUE;
 	char *input;
 
 
@@ -608,7 +622,6 @@ linphonec_main_loop (LinphoneCore * opm, char * sipAddr)
 	while ((input=readline(prompt)))
 	{
 		char *iptr; /* input and input pointer */
-		char *tmp;
 		size_t input_len;
 
 		/* Strip blanks */
@@ -633,22 +646,9 @@ linphonec_main_loop (LinphoneCore * opm, char * sipAddr)
 		 */
 		if ( strcmp(last_in_history, iptr) )
 		{
-			if ( strlen(last_in_history) < input_len )
-			{
-				tmp=realloc(last_in_history,
-					sizeof(char)*(input_len+1));
-				if ( tmp ) last_in_history=tmp;
-				else /* OOM */
-				{
-					free(last_in_history);
-					last_in_history=NULL;
-				}
-			}
-			if ( last_in_history ) /* NULL on OOM */
-			{
-				strcpy(last_in_history, iptr);
-				add_history(iptr);
-			}
+			strncpy(last_in_history,iptr,sizeof(last_in_history));
+			last_in_history[sizeof(last_in_history)-1]='\0';
+			add_history(iptr);
 		}
 
 		linphonec_parse_command_line(&linphonec, iptr);
@@ -694,10 +694,7 @@ linphonec_parse_cmdline(int argc, char **argv)
 		{
 			if ( ++arg_num >= argc ) print_usage(EXIT_FAILURE);
 
-			if (!g_file_test (argv[arg_num],
-				G_FILE_TEST_EXISTS) ||
-			    g_file_test (argv[arg_num],
-				G_FILE_TEST_IS_DIR))
+			if (access(argv[arg_num],F_OK)!=0 )
 			{
 				fprintf (stderr,
 					"Cannot open config file %s.\n",
@@ -761,25 +758,25 @@ handle_configfile_migration()
 	char *new_cfg;
 	const char *home = getenv("HOME");
 
-	new_cfg = g_strdup_printf("%s/.linphonerc", home);
+	new_cfg = ms_strdup_printf("%s/.linphonerc", home);
 
 	/*
 	 * If the *NEW* configuration already exists
 	 * do nothing.
 	 */
-	if (g_file_test (new_cfg, G_FILE_TEST_EXISTS))
+	if (access(new_cfg,F_OK)==0)
 	{
 		free(new_cfg);
 		return 0;
 	}
 
-	old_cfg_cli = g_strdup_printf("%s/.linphonec", home);
+	old_cfg_cli = ms_strdup_printf("%s/.linphonec", home);
 
 	/*
 	 * If the *OLD* CLI configurations exist copy it to
 	 * the new file and make it a symlink.
 	 */
-	if (g_file_test (old_cfg_cli, G_FILE_TEST_EXISTS))
+	if (access(old_cfg_cli, F_OK)==0)
 	{
 		if ( ! copy_file(old_cfg_cli, new_cfg) )
 		{
@@ -794,13 +791,13 @@ handle_configfile_migration()
 	}
 
 	free(old_cfg_cli);
-	old_cfg_gui = g_strdup_printf("%s/.gnome2/linphone", home);
+	old_cfg_gui = ms_strdup_printf("%s/.gnome2/linphone", home);
 
 	/*
 	 * If the *OLD* GUI configurations exist copy it to
 	 * the new file and make it a symlink.
 	 */
-	if (g_file_test (old_cfg_gui, G_FILE_TEST_EXISTS))
+	if (access(old_cfg_gui, F_OK)==0)
 	{
 		if ( ! copy_file(old_cfg_gui, new_cfg) )
 		{
@@ -924,6 +921,22 @@ lpc_strip_blanks(char *input)
 /****************************************************************************
  *
  * $Log: linphonec.c,v $
+ * Revision 1.51  2006/08/21 12:49:59  smorlat
+ * merged several little patches.
+ *
+ * Revision 1.50  2006/07/26 08:17:28  smorlat
+ * fix bugs.
+ *
+ * Revision 1.49  2006/07/17 18:45:00  smorlat
+ * support for several event queues in ortp.
+ * glib dependency removed from coreapi/ and console/
+ *
+ * Revision 1.48  2006/04/09 12:45:32  smorlat
+ * linphonec improvements.
+ *
+ * Revision 1.47  2006/04/04 08:04:34  smorlat
+ * switched to mediastreamer2, most bugs fixed.
+ *
  * Revision 1.46  2006/03/16 17:17:40  smorlat
  * fix various bugs.
  *
