@@ -121,9 +121,15 @@ void linphone_call_destroy(LinphoneCall *obj)
 
 LinphoneCallLog * linphone_call_log_new(LinphoneCall *call, char *from, char *to){
 	LinphoneCallLog *cl=ms_new0(LinphoneCallLog,1);
+	struct tm loctime;
 	cl->lc=call->core;
 	cl->dir=call->dir;
-	cl->start_date=ms_strdup(ctime(&call->start_time));
+#ifdef WIN32
+	loctime=*localtime(&call->start_time);
+#else
+	localtime_r(&call->start_time,&loctime);
+#endif
+	strftime(cl->start_date,sizeof(cl->start_date),"%c",&loctime);
 	cl->from=from;
 	cl->to=to;
 	return cl;
@@ -177,7 +183,7 @@ char * linphone_call_log_to_str(LinphoneCallLog *cl){
 		default:
 			status="unknown";
 	}
-	return ortp_strdup_printf(_("%s at %sFrom: %s\nTo: %s\nStatus: %s\nDuration: %i mn %i sec\n"),
+	return ortp_strdup_printf(_("%s at %s\nFrom: %s\nTo: %s\nStatus: %s\nDuration: %i mn %i sec\n"),
 			(cl->dir==LinphoneCallIncoming) ? _("Incoming call") : _("Outgoing call"),
 			cl->start_date,
 			cl->from,
@@ -188,7 +194,6 @@ char * linphone_call_log_to_str(LinphoneCallLog *cl){
 }
 
 void linphone_call_log_destroy(LinphoneCallLog *cl){
-	if (cl->start_date!=NULL) ms_free(cl->start_date);
 	if (cl->from!=NULL) osip_free(cl->from);
 	if (cl->to!=NULL) osip_free(cl->to);
 	ms_free(cl);
