@@ -184,7 +184,7 @@ typedef struct _LinphoneCallLog{
 	LinphoneCallStatus status;
 	char *from;
 	char *to;
-	char *start_date;
+	char start_date[128];
 	int duration;
 	
 } LinphoneCallLog;
