@@ -185,55 +185,42 @@ int payload_type_get_rate(PayloadType *pt){
 	return pt->clock_rate;
 }
 
-static int get_bandwidth(const LinphoneCore *lc){
-	int dbw=linphone_core_get_download_bandwidth(lc);
-	int ubw=linphone_core_get_upload_bandwidth(lc);
-	if (dbw==0)
-		dbw=1<<30;
-	if (ubw==0)
-		ubw=1<<30;
-	return MIN(dbw,ubw);
-}
-
-
 /* return TRUE if codec can be used with bandwidth, FALSE else*/
 bool_t linphone_core_check_payload_type_usability(const LinphoneCore *lc, PayloadType *pt)
 {
-	bool_t ret=FALSE;
 	double codec_band;
 	double npacket;
 	double packet_size;
-	double bandwidth=get_bandwidth(lc)*1000.0;	
-
-	/*ms_message("Bandwidth is %g",bandwidth);*/
+	int min_audio_bw=get_min_bandwidth(lc->dw_audio_bw,lc->up_audio_bw);
+	int min_video_bw=get_min_bandwidth(lc->dw_video_bw,lc->up_video_bw);
+	bool_t ret=FALSE;
 	
 	switch (pt->type){
 		case PAYLOAD_AUDIO_CONTINUOUS:
 		case PAYLOAD_AUDIO_PACKETIZED:
 			if (strcmp("speex",pt->mime_type)==0 && pt->clock_rate==8000){
-				if ((bandwidth<=128000 && lc->video_conf.enabled) ||
-					bandwidth<=64000)
-					pt->normal_bitrate=8000;
-				else
+				if (bandwidth_is_greater(min_audio_bw,28))
 					pt->normal_bitrate=20000;
+				else
+					pt->normal_bitrate=8000;
 			}
 			/* very approximative estimation... revisit*/
 			npacket=50;
 			packet_size=(double)(pt->normal_bitrate/(50*8))+UDP_HDR_SZ+RTP_HDR_SZ+IP4_HDR_SZ;
 			codec_band=packet_size*8.0*npacket;
-			ret=(codec_band<bandwidth);
+			ret=bandwidth_is_greater(min_audio_bw*1000,codec_band);
 			//ms_message("Payload %s: %g",pt->mime_type,codec_band);
 			break;
 		case PAYLOAD_VIDEO:
-			if (bandwidth>=128000) {
+			if (bandwidth_is_greater(min_video_bw,0)) {
 				if (strcmp(pt->mime_type,"H263-1998")==0){
 					payload_type_set_recv_fmtp(pt,"CIF=1;QCIF=1");
 				}
 				/*let the video use all the bandwidth minus the maximum bandwidth used by audio */
-				if (bandwidth<=1000000)
-					pt->normal_bitrate=bandwidth-64000;
+				if (min_video_bw>0)
+					pt->normal_bitrate=min_video_bw*1000;
 				else 
-					pt->normal_bitrate=1000000;
+					pt->normal_bitrate=512000;
 				ret=TRUE;
 			}
 			else ret=FALSE;
@@ -261,13 +248,7 @@ MSList *fix_codec_list(RtpProfile *prof, MSList *conflist)
 				if (payload_type_get_user_data(payload)==NULL){
 					payload_type_set_user_data(payload,(void*)desc->text);
 					payload_type_set_enable(payload,payload_type_enabled(confpayload));
-					/*hack: put theora first */
-					if (strcasecmp(payload->mime_type,"x-theora")==0){
-						newlist=ms_list_prepend(newlist,(void *)payload);
-					}else{
-						newlist=ms_list_append(newlist,(void *)payload);
-					}
-					
+					newlist=ms_list_append(newlist,payload);
 				}/*else this is a duplicate */
 			}
 		}
