@@ -79,6 +79,17 @@ void linphone_core_get_local_ip(LinphoneCore *lc, const char *to, char *result);
 bool_t host_has_ipv6_network();
 bool_t lp_spawn_command_line_sync(const char *command, char **result,int *command_ret);
 
+static inline int get_min_bandwidth(int dbw, int ubw){
+	if (dbw<0) return ubw;
+	if (ubw<0) return dbw;
+	return MIN(dbw,ubw);
+}
+
+static inline bool_t bandwidth_is_greater(int bw1, int bw2){
+	if (bw1<0) return TRUE;
+	else if (bw2<0) return FALSE;
+	else return bw1>=bw2;
+}
 
 #define PAYLOAD_TYPE_ENABLED	PAYLOAD_TYPE_USER_FLAG_0
 
