@@ -174,6 +174,7 @@ void linphone_proxy_config_done(LinphoneProxyConfig *obj)
 	obj->frozen=FALSE;
 	if (obj->reg_sendregister){
 		char *ct=NULL;
+		#if 0
 		{
 			char localip[LINPHONE_IPADDR_SIZE];
 			linphone_core_get_local_ip(obj->lc,NULL,localip);
@@ -187,6 +188,7 @@ void linphone_proxy_config_done(LinphoneProxyConfig *obj)
 			osip_from_to_str(identity,&ct);
 			osip_from_free(identity);
 		}
+		#endif 
 		obj->rid=eXosip_register_init((char*)id_str,obj->reg_proxy,ct,obj->reg_route);
 		linphone_proxy_config_register(obj);
 		if (ct!=NULL) osip_free(ct);
@@ -203,7 +205,7 @@ void linphone_proxy_config_set_realm(LinphoneProxyConfig *cfg, const char *realm
 }
 
 void linphone_core_update_proxy_register(LinphoneCore *lc){
-	MSList *elem;
+	const MSList *elem;
 	for(elem=linphone_core_get_proxy_config_list(lc);elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*) elem->data;
 		if (cfg->reg_sendregister && cfg->rid>=0){
@@ -470,7 +472,7 @@ void linphone_core_retry_proxy_register(LinphoneCore *lc, const char *realm)
 	}
 }
 
-MSList *linphone_core_get_proxy_config_list(LinphoneCore *lc){
+const MSList *linphone_core_get_proxy_config_list(const LinphoneCore *lc){
 	return lc->sip_conf.proxies;
 }
 
