@@ -961,9 +961,10 @@ osip_message_t *eXosip_prepare_request_for_auth(osip_message_t *msg)
   newmsg->cseq->number=strdup_printf("%i",cseq+1);
 
   osip_list_remove(newmsg->vias, 0);
+	locip=osip_strdup(osip_via_get_host(via));
   osip_via_free(via);
 #ifdef SM
-  eXosip_get_localip_for(newmsg->req_uri->host,&locip);
+	
 #else
   eXosip_guess_ip_for_via(eXosip.ip_family, locip, 49);
 #endif
@@ -2313,9 +2314,9 @@ eXosip_update_top_via(osip_message_t *sip)
 
 
   osip_list_remove(sip->vias, 0);
+	locip=osip_strdup(osip_via_get_host(via));
   osip_via_free(via);
 #ifdef SM
-  eXosip_get_localip_for(sip->req_uri->host,&locip);
 #else
   eXosip_guess_ip_for_via(eXosip.ip_family, locip, 49);
 #endif
@@ -2478,7 +2479,10 @@ int eXosip_register      (int rid, int registration_period)
        //!jinti! if exist outbound proxy setting ,register must use outboundproxy!
        if (jr->r_route!=NULL)
        {
-         osip_message_set_route(reg, jr->r_route);
+	 osip_route_t *r=NULL;
+	 osip_message_get_route(reg,0,&r);
+	 if (r==NULL)
+         	osip_message_set_route(reg, jr->r_route);
        }
 	
   i = osip_transaction_init(&transaction,
