@@ -191,6 +191,7 @@ struct eXosip_reg_t {
   int             r_reg_period;     /* delay between registration */
   char           *r_aor;            /* sip identity */
   char           *r_registrar;      /* registrar */
+  char           *r_route;          /* outbound proxy */
 #if 0
   eXosip_realm_t *r_realms;         /* list of realms */
 #endif
@@ -404,7 +405,7 @@ int  generating_ack_for_2xx(osip_message_t **ack, osip_dialog_t *dialog);
 int  generating_info(osip_message_t **info, char *from, char *to, char *proxy);
 
 int  _eXosip_reg_find(eXosip_reg_t **reg, osip_transaction_t *tr);
-int  eXosip_reg_init(eXosip_reg_t **jr, char *from, char *proxy, char *contact);
+int  eXosip_reg_init(eXosip_reg_t **jr, char *from, char *proxy, char *contact, char* route);
 void eXosip_reg_free(eXosip_reg_t *jreg);
 int  generating_register(osip_message_t **reg, char *transport, char *from, char *proxy, int expires);
 char *generating_sdp_answer(osip_message_t *request, osip_negotiation_ctx_t *context);
