@@ -276,14 +276,14 @@ __eXosip_create_authorization_header(osip_message_t *previous_answer,
   {   
     char * pszNonce = osip_strdup_without_quote(osip_www_authenticate_get_nonce(wa));
     char * pszCNonce = osip_strdup_without_quote("abcdefghi");
-    const char * pszUser = osip_strdup_without_quote(username);
+    char * pszUser = osip_strdup_without_quote(username);
     char * pszRealm = osip_strdup_without_quote(osip_authorization_get_realm(aut));
-    const char * pszPass=NULL;
+	const char * pszPass=NULL;
     char * pszAlg = osip_strdup("MD5");
     char *szNonceCount = NULL;
-    const char * pszMethod = osip_strdup_without_quote(previous_answer->cseq->method);
+    char * pszMethod = osip_strdup_without_quote(previous_answer->cseq->method);
     char * pszQop = NULL;
-    const char * pszURI = osip_strdup_without_quote(rquri);
+    char * pszURI = osip_strdup_without_quote(rquri);
 
     szNonceCount = osip_strdup("00000000");
     sprintf(szNonceCount, "%08d", nc++);
