@@ -169,11 +169,26 @@ eXosip_event_init_for_call(int type,
 		  osip_free(tmp);
 		}
 	    }
-	  if (tr!=NULL && tr->last_response!=NULL)
-	    {
-	      snprintf(je->reason_phrase, 49, "%s", tr->last_response->reason_phrase);
-	      je->status_code = tr->last_response->status_code;
-	    }
+	  
+	}else{
+		osip_transaction_t *tr;
+		char *tmp;
+		tr=eXosip_find_last_invite(jc,NULL);
+		/* no dialog established but we need to fill remote_contact */
+		if (tr!=NULL && tr->last_response!=NULL)
+		{
+			osip_contact_t *ctt=NULL;
+			snprintf(je->reason_phrase, 49, "%s", tr->last_response->reason_phrase);
+			je->status_code = tr->last_response->status_code;
+			osip_message_get_contact(tr->last_response,0,&ctt);
+			if (ctt){
+				tmp=NULL;
+				osip_contact_to_str(ctt,&tmp);
+				if (tmp){
+					strncpy(je->remote_contact,tmp,255);
+				}
+			}
+		}
 	}
     }
   
