@@ -426,14 +426,18 @@ generating_register(osip_message_t **reg, char *from,
 		    char *proxy, char *contact, int expires)
 {
   osip_from_t *a_from;
+  osip_via_t *via;
   int i;
-  char locip[50];
+  char * locip;
 
   i = generating_request_out_of_dialog(reg, "REGISTER", NULL, "UDP",
 				       from, proxy);
   if (i!=0) return -1;
 
-  eXosip_guess_ip_for_via(eXosip.ip_family, locip, 49);
+  /*get the local ip from the via already established by generating_request_out_of_dialog */
+  if (osip_message_get_via((*reg),0,&via)==0){
+    locip=via->host;
+  }else return -1;
 
   if (contact==NULL)
     {
@@ -445,59 +449,15 @@ generating_register(osip_message_t **reg, char *from,
 	  && a_from->url!=NULL && a_from->url->username!=NULL )
 	{
 	  contact = (char *) osip_malloc(50+strlen(a_from->url->username));
-	  if (eXosip.j_firewall_ip[0]!='\0')
-	    {
-		#if 0
-	      char *c_address = (*reg)->req_uri->host;
-
-		  struct addrinfo *addrinfo;
-		  struct __eXosip_sockaddr addr;
-		  i = eXosip_get_addrinfo(&addrinfo, (*reg)->req_uri->host, 5060);
-		  if (i==0)
-			{
-			  memcpy (&addr, addrinfo->ai_addr, addrinfo->ai_addrlen);
-			  freeaddrinfo (addrinfo);
-			  c_address = inet_ntoa (((struct sockaddr_in *) &addr)->sin_addr);
-			  OSIP_TRACE (osip_trace
-				  (__FILE__, __LINE__, OSIP_INFO1, NULL,
-				  "eXosip: here is the resolved destination host=%s\n", c_address));
-			}
-
-	      if (eXosip_is_public_address(c_address))
-		{
-		#endif
-		  if (eXosip.localport==NULL)
-		    sprintf(contact, "<sip:%s@%s>", a_from->url->username,
-			    eXosip.j_firewall_ip);
-		  else
-		    sprintf(contact, "<sip:%s@%s:%s>", a_from->url->username,
-			    eXosip.j_firewall_ip,
-			    eXosip.localport);
-		#if 0
-		}
-	      else
-		{
-		  if (eXosip.localport==NULL)
-		    sprintf(contact, "<sip:%s@%s>", a_from->url->username,
-			    locip);
-		  else
-		    sprintf(contact, "<sip:%s@%s:%s>", a_from->url->username,
-			    locip,
-			    eXosip.localport);
-		}
-		#endif
-	    }
-	  else
-	    {
-	      if (eXosip.localport==NULL)
-		sprintf(contact, "<sip:%s@%s>", a_from->url->username,
-			locip);
-	      else
-		sprintf(contact, "<sip:%s@%s:%s>", a_from->url->username,
-			locip,
-			eXosip.localport);
-	    }
 	  
+		if (eXosip.ip_family==AF_INET6)
+			sprintf(contact, "<sip:%s@[%s]:%s>", a_from->url->username,
+			locip,
+			eXosip.localport!=NULL ? eXosip.localport : "5060");
+		else
+			sprintf(contact, "<sip:%s@%s:%s>", a_from->url->username,
+			locip,
+			eXosip.localport!=NULL ? eXosip.localport : "5060");
 	  osip_message_set_contact(*reg, contact);
 	  osip_free(contact);
 	}
