@@ -2119,6 +2119,20 @@ static void eXosip_process_response_out_of_transaction (osip_event_t *evt)
   osip_event_free(evt);
 }
 
+static void fix_via(osip_message_t *msg, const struct sockaddr * sa, socklen_t sa_len){
+	char host[NI_MAXHOST];
+	char serv[NI_MAXSERV];
+	int err;
+	err=getnameinfo(sa, sa_len,host,NI_MAXHOST,serv,NI_MAXSERV,
+		NI_NUMERICHOST|NI_NUMERICSERV);
+	if (err!=0){
+		OSIP_TRACE(osip_trace(__FILE__,__LINE__,OSIP_ERROR,NULL,
+				"sockaddr_to_char: error in getnameinfo():%s\n",gai_strerror(err) ));
+		return;
+	}
+	osip_message_fix_last_via_header(msg,host,atoi(serv));
+}
+
 /* if second==-1 && useconds==-1  -> wait for ever
    if max_message_nb<=0  -> infinite loop....  */
 int eXosip_read_message   ( int max_message_nb, int sec_max, int usec_max )
@@ -2204,25 +2218,7 @@ int eXosip_read_message   ( int max_message_nb, int sec_max, int usec_max )
 	      transaction = NULL;
 	      if (sipevent!=NULL&&sipevent->sip!=NULL)
 		{
-		   char out_addr[INET6_ADDRSTRLEN];
-
-                   if(eXosip.ip_family == AF_INET){                  
-                       osip_message_fix_last_via_header(sipevent->sip, 
-                                                        inet_ntop (AF_INET,
-                                                                   (void *)&(((struct sockaddr_in *)&sa)->sin_addr).s_addr,
-                                                                   out_addr,
-                                                                   INET_ADDRSTRLEN),
-                                                        ntohs(((struct sockaddr_in *)&sa)->sin_port));
-							
-					}
-                   else{
-                       osip_message_fix_last_via_header(sipevent->sip, 
-                                                        inet_ntop (AF_INET6, 
-                                                                   (void *)&(((struct sockaddr_in6 *)&sa)->sin6_addr).s6_addr, 
-                                                                   out_addr,
-                                                                   INET6_ADDRSTRLEN),
-                                                       ntohs (((struct sockaddr_in6 *)&sa)->sin6_port));                  
-					}
+		  fix_via(sipevent->sip,(struct sockaddr*)&sa,slen);
 		  i = osip_find_transaction_and_add_event(eXosip.j_osip, sipevent);
 		  if (i!=0)
 		    {
