@@ -223,7 +223,7 @@ GtkWidget *create_and_fill_address_book(){
 	gtk_tree_view_set_model(GTK_TREE_VIEW(address_list),GTK_TREE_MODEL(store));
 	g_object_unref(G_OBJECT(store));
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes ("Contact list",
+	column = gtk_tree_view_column_new_with_attributes (_("Contact list"),
                                                    renderer,
                                                    "text", SIP_ADDRESS_COLUMN,
                                                    NULL);
