@@ -312,8 +312,10 @@ on_property_box_closed                 (GnomeDialog     *gnomedialog,
 void
 on_address_book_close                  (GtkObject       *object,
                                         gpointer         user_data);
-										
-#define VERSION LINPHONE_VERSION
+
+#ifndef VERSION
+# define VERSION LINPHONE_VERSION
+#endif
 
 void
 on_addfriend_clicked                   (GtkButton       *button,
@@ -482,3 +484,57 @@ on_addressentry_activate               (GtkEntry        *entry,
 void
 on_addressentry_destroy                (GtkObject       *object,
                                         gpointer         user_data);
+
+void
+on_download_bw_value_changed           (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_download_bw_editing_done            (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_download_bw_changed                 (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+gboolean
+on_upload_bw_output                    (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_upload_bw_change_value              (GtkSpinButton   *spinbutton,
+                                        GtkScrollType    scroll,
+                                        gpointer         user_data);
+
+void
+on_upload_bw_value_changed             (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+gboolean
+on_upload_bw_leave_notify_event        (GtkWidget       *widget,
+                                        GdkEventCrossing *event,
+                                        gpointer         user_data);
+
+void
+on_video_enabled_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_echocancelation_toggled             (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_no_nat_toggled                      (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_use_stun_toggled                    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_static_nat_toggled                  (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_stun_server_changed                 (GtkEditable     *editable,
+                                        gpointer         user_data);
