@@ -78,7 +78,6 @@ void net_selection_changed_cb(GtkTreeSelection *select, gpointer userdata)
 void net_section_fill(NetSection *sec,LinphoneCore *lc)
 {
 	gfloat value;
-	bool_t use_nat;
 	const gchar *nat_address,*stun_server;
 	
 	value=(gfloat)linphone_core_get_audio_jittcomp(lc);
@@ -91,12 +90,11 @@ void net_section_fill(NetSection *sec,LinphoneCore *lc)
 	
 	/* nat setup */
 	nat_address=linphone_core_get_nat_address(lc);
-	use_nat=linphone_core_nat_address_used(lc);
 	
-	if (use_nat)
+	if (linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_NAT_ADDRESS)
 		gtk_toggle_button_set_active(
 			GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"static_nat"))
-				,use_nat);
+				,TRUE);
 	
 	if (nat_address!=NULL) {
 		gtk_entry_set_text(GTK_ENTRY(sec->nat_address),nat_address);
@@ -106,10 +104,10 @@ void net_section_fill(NetSection *sec,LinphoneCore *lc)
 		gtk_entry_set_text(
 		GTK_ENTRY(lookup_widget(get_property_box()->prop,"stun_server")),
 		stun_server);
-	if (!use_nat)
+	if (linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_STUN)
 		gtk_toggle_button_set_active(
-			GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"use_stun")),
-			linphone_core_stun_enabled(lc));
+			GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"use_stun")),TRUE);
+	
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->use_sipinfo),
 		linphone_core_get_use_info_for_dtmf(lc));
@@ -121,11 +119,6 @@ void
 on_enable_nat_toggled                  (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
-	LinphonePropertyBox *prop=get_property_box();
-	NetSection *sec=&prop->net;
-	gboolean use_nat;
-	use_nat=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->enable_nat));
-	linphone_core_use_nat_address(get_core(),use_nat);
 	property_box_changed();
 	
 }
@@ -156,7 +149,6 @@ void net_section_apply(NetSection *sec,LinphoneCore *lc)
 			lookup_widget(get_property_box()->prop,"static_nat")));
 	name=gtk_editable_get_chars(GTK_EDITABLE(sec->nat_address),0,-1);
 	linphone_core_set_nat_address(lc,name);
-	linphone_core_use_nat_address(lc,use_nat);
 	g_free(name);
 
 	use_stun=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
@@ -165,7 +157,12 @@ void net_section_apply(NetSection *sec,LinphoneCore *lc)
 			lookup_widget(get_property_box()->prop,"stun_server") ),0,-1);
 	linphone_core_set_stun_server(lc,name);
 	g_free(name);
-	linphone_core_enable_stun(lc,use_stun);
+	if (use_stun) linphone_core_set_firewall_policy(lc,
+			LINPHONE_POLICY_USE_STUN);
+	else if (use_nat) linphone_core_set_firewall_policy(lc,
+			LINPHONE_POLICY_USE_NAT_ADDRESS);
+	else linphone_core_set_firewall_policy(lc,
+			LINPHONE_POLICY_NO_FIREWALL);
 	
 	{
 	/* get the value of jitt_comp*/
@@ -215,7 +212,7 @@ void sip_section_init(SipSection *sec,GtkWidget *prop)
 
 
 void proxy_list_fill(GtkTreeModel *model, LinphoneCore *lc){
-	MSList *elem;
+	const MSList *elem;
 	GtkTreeIter iter;
 	/* fill the proxy list */
 	gtk_list_store_clear(GTK_LIST_STORE(model));
@@ -395,14 +392,15 @@ on_proxy_config_box_response           (GtkDialog       *dialog,
 void codec_section_init(CodecSection *sec, GtkWidget *prop)
 {
 	sec->au_codec_list=lookup_widget(prop,"au_codec_list");
+	sec->vi_codec_list=lookup_widget(prop,"vid_codec_list");
 	sec->codec_info=lookup_widget(prop,"codec_info");
 }
 
 void codec_selection_changed_cb(GtkTreeSelection *selection, gpointer data)
 {
 	GtkTreeIter iter;
-    GtkTreeModel *model;
-    struct _PayloadType *pt=NULL;
+	GtkTreeModel *model;
+	struct _PayloadType *pt=NULL;
 	LinphonePropertyBox *prop=get_property_box();
 	
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))	
@@ -491,7 +489,9 @@ void codec_section_fill(CodecSection *sec, LinphoneCore *lc, GtkWidget *propbox)
 	/* display prefered codecs*/
 	int value;
 	const MSList *audio_codecs=linphone_core_get_audio_codecs(lc);
+	const MSList *video_codecs=linphone_core_get_video_codecs(lc);
 	codec_list_build(GTK_TREE_VIEW(sec->au_codec_list),audio_codecs);
+	codec_list_build(GTK_TREE_VIEW(lookup_widget(propbox,"vid_codec_list")),video_codecs);
 	value=linphone_core_get_download_bandwidth(lc);
 	if (value!=0)
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(propbox,"download_bw")),value);
@@ -521,6 +521,18 @@ void codec_section_apply(CodecSection *sec, LinphoneCore *lc)
 		codeclist=ms_list_append(codeclist,pt);
 	}while (gtk_tree_model_iter_next(model,&iter));
 	linphone_core_set_audio_codecs(lc,codeclist);
+	model=gtk_tree_view_get_model(GTK_TREE_VIEW(sec->vi_codec_list));
+	/* retrieve the codec list */
+	codeclist=NULL;
+	g_return_if_fail(gtk_tree_model_get_iter_first(model,&iter));
+	do{
+		gtk_tree_model_get (model, &iter, CODEC_STATUS,&status,CODEC_PRIVDATA, &pt,-1);
+		g_return_if_fail(pt!=NULL);
+		if (strcmp(status,_("Enabled"))==0) payload_type_set_enable(pt,1);
+		else payload_type_set_enable(pt,0);
+		codeclist=ms_list_append(codeclist,pt);
+	}while (gtk_tree_model_iter_next(model,&iter));
+	linphone_core_set_video_codecs(lc,codeclist);
 }
 
 void sound_section_init(SoundSection *sec, GtkWidget *prop)
@@ -813,14 +825,23 @@ void codec_row_move(GtkTreeView *listview, int action)
 	}
 }
 
+static void codec_move(int action){
+	GtkTreeView *listview;
+	int page=gtk_notebook_get_current_page(GTK_NOTEBOOK(
+		lookup_widget(get_property_box()->prop,"codec_notebook")));
+	if (page==0)
+		listview=GTK_TREE_VIEW(get_property_box()->codec.au_codec_list);
+	else 
+		listview=GTK_TREE_VIEW(lookup_widget(get_property_box()->prop,"vid_codec_list"));
+	codec_row_move(listview,action);
+	property_box_changed();
+}
+
 void
 on_aucodec_up_clicked                  (GtkButton       *button,
                                         gpointer         user_data)
 {
-	LinphonePropertyBox *prop=get_property_box();
-	GtkTreeView *listview=GTK_TREE_VIEW(prop->codec.au_codec_list);
-	codec_row_move(listview,CODEC_ACTION_UP);
-	property_box_changed();
+	codec_move(CODEC_ACTION_UP);
 }
 
 
@@ -828,10 +849,7 @@ void
 on_aucodec_down_clicked                (GtkButton       *button,
                                         gpointer         user_data)
 {
-	LinphonePropertyBox *prop=get_property_box();
-	GtkTreeView *listview=GTK_TREE_VIEW(prop->codec.au_codec_list);
-	codec_row_move(listview,CODEC_ACTION_DOWN);
-	property_box_changed();
+	codec_move(CODEC_ACTION_DOWN);
 }
 
 void codec_set_status(GtkTreeView *listview,gboolean status)
@@ -869,13 +887,23 @@ void codec_list_update(GtkTreeView *listview)
 	}while (gtk_tree_model_iter_next(model,&iter));
 }
 
+static void codec_enable(gboolean val){
+	GtkTreeView *listview;
+	int page=gtk_notebook_get_current_page(GTK_NOTEBOOK(
+		lookup_widget(get_property_box()->prop,"codec_notebook")));
+	if (page==0)
+		listview=GTK_TREE_VIEW(get_property_box()->codec.au_codec_list);
+	else 
+		listview=GTK_TREE_VIEW(lookup_widget(get_property_box()->prop,"vid_codec_list"));
+	codec_set_status(listview,val);
+	property_box_changed();
+}
 
 void
 on_aucodec_enable_clicked              (GtkButton       *button,
                                         gpointer         user_data)
 {
-	codec_set_status(GTK_TREE_VIEW(get_property_box()->codec.au_codec_list),TRUE);
-	property_box_changed();
+	codec_enable(TRUE);
 }
 
 
@@ -883,8 +911,7 @@ void
 on_aucodec_disable_clicked             (GtkButton       *button,
                                         gpointer         user_data)
 {
-	codec_set_status(GTK_TREE_VIEW(get_property_box()->codec.au_codec_list),FALSE);
-	property_box_changed();
+	codec_enable(FALSE);
 }
 
 
@@ -987,6 +1014,7 @@ on_download_bw_value_changed           (GtkSpinButton   *spinbutton,
 	if (val==0) gtk_entry_set_text(GTK_ENTRY(spinbutton),_("Unlimited"));
 	linphone_core_set_download_bandwidth(get_core(),(int)val);
 	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"au_codec_list")));
+	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"vid_codec_list")));
 }
 
 void
@@ -997,6 +1025,7 @@ on_upload_bw_value_changed             (GtkSpinButton   *spinbutton,
 	if (val==0) gtk_entry_set_text(GTK_ENTRY(spinbutton),_("Unlimited"));
 	linphone_core_set_upload_bandwidth(get_core(),(int)val);
 	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"au_codec_list")));
+	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"vid_codec_list")));
 }
 
 void
