@@ -52,7 +52,8 @@ typedef struct MSVideoSize{
 typedef enum{
 	MS_YUV420P,
 	MS_YV12,
-	MS_RGB24
+	MS_RGB24,
+	MS_MJPEG
 }MSPixFmt;
 
 int ms_pix_fmt_to_ffmpeg(MSPixFmt fmt);
