@@ -26,6 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer2/mssndcard.h"
 
 static MSSndCard * alsa_card_new(int id);
+static MSSndCard *alsa_card_duplicate(MSSndCard *obj);
 static MSFilter * ms_alsa_read_new(const char *dev);
 static MSFilter * ms_alsa_write_new(const char *dev);
 
@@ -461,9 +462,20 @@ MSSndCardDesc alsa_card_desc={
 	.set_capture=alsa_card_set_source,
 	.create_reader=alsa_card_create_reader,
 	.create_writer=alsa_card_create_writer,
-	.uninit=alsa_card_uninit
+	.uninit=alsa_card_uninit,
+	.duplicate=alsa_card_duplicate
 };
 
+static MSSndCard *alsa_card_duplicate(MSSndCard *obj){
+	MSSndCard *card=ms_snd_card_new(&alsa_card_desc);
+	AlsaData* dcard=(AlsaData*)card->data;
+	AlsaData* dobj=(AlsaData*)obj->data;
+	card->name=ms_strdup(obj->name);
+	dcard->pcmdev=ms_strdup(dobj->pcmdev);
+	dcard->mixdev=ms_strdup(dobj->mixdev);
+	return obj;
+}
+
 static MSSndCard * alsa_card_new(int id)
 {
 	MSSndCard * obj;
