@@ -27,14 +27,20 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "alldescs.h"
 #include "mediastreamer2/mssndcard.h"
 
+#if !defined(_WIN32_WCE)
 #include <sys/types.h>
+#endif
 #ifndef WIN32
 #include <dirent.h>
 #else
 #ifndef PACKAGE_PLUGINS_DIR
+#if defined(WIN32) || defined(_WIN32_WCE)
+#define PACKAGE_PLUGINS_DIR "plugins\\"
+#else
 #define PACKAGE_PLUGINS_DIR "."
 #endif
 #endif
+#endif
 #ifdef HAVE_DLOPEN
 #include <dlfcn.h>
 #endif
@@ -152,7 +158,7 @@ MSList *ms_list_find_custom(MSList *list, int (*compare_func)(const void *, cons
 	return NULL;
 }
 
-void * ms_list_nth_data(MSList *list, int index){
+void * ms_list_nth_data(const MSList *list, int index){
 	int i;
 	for(i=0;list!=NULL;list=list->next,++i){
 		if (i==index) return list->data;
@@ -161,7 +167,7 @@ void * ms_list_nth_data(MSList *list, int index){
 	return NULL;
 }
 
-int ms_list_position(MSList *list, MSList *elem){
+int ms_list_position(const MSList *list, MSList *elem){
 	int i;
 	for(i=0;list!=NULL;list=list->next,++i){
 		if (elem==list) return i;
@@ -170,7 +176,7 @@ int ms_list_position(MSList *list, MSList *elem){
 	return -1;
 }
 
-int ms_list_index(MSList *list, void *data){
+int ms_list_index(const MSList *list, void *data){
 	int i;
 	for(i=0;list!=NULL;list=list->next,++i){
 		if (data==list->data) return i;
@@ -211,27 +217,32 @@ MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(cons
 
 typedef void (*init_func_t)(void);
 
-void ms_load_plugins(const char *dir){
-#ifdef WIN32
+int ms_load_plugins(const char *dir){
+    int num=0;
+#if defined(WIN32) && !defined(_WIN32_WCE)
     WIN32_FIND_DATA FileData; 
     HANDLE hSearch; 
-    char szDirPath[] = "plugins\\"; 
-    char szPluginFile[256]; 
+    char szDirPath[1024]; 
+    char szPluginFile[1024]; 
     BOOL fFinished = FALSE;
     
+	snprintf(szDirPath, sizeof(szDirPath), "%s", dir);
     // Create a new directory.    
     if (!CreateDirectory(szDirPath, NULL))
     {
-        ms_message("plugins directory already exist.");
+        ms_message("plugins directory already exist (%s).", szDirPath);
     }
     
     // Start searching for .TXT files in the current directory.
     
-    hSearch = FindFirstFile("plugins\\*.dll", &FileData);
+	snprintf(szDirPath, sizeof(szDirPath), "%s\\*.dll", dir);
+    hSearch = FindFirstFile(szDirPath, &FileData);
     if (hSearch == INVALID_HANDLE_VALUE)
     {
-        ms_message("no plugin (*.dll) found.");
+        ms_message("no plugin (*.dll) found in %s.", szDirPath);
+		return 0;
     }
+	snprintf(szDirPath, sizeof(szDirPath), "%s", dir);
 
     while (!fFinished) 
     {
@@ -240,7 +251,7 @@ void ms_load_plugins(const char *dir){
         UINT em;
         em = SetErrorMode (SEM_FAILCRITICALERRORS);
 
-        snprintf(szPluginFile, 256, "plugins\\%s", FileData.cFileName);
+        snprintf(szPluginFile, sizeof(szPluginFile), "%s\\%s", szDirPath, FileData.cFileName);
         os_handle = LoadLibraryEx (szPluginFile, NULL, LOAD_WITH_ALTERED_SEARCH_PATH);
         if (os_handle==NULL)
         {
@@ -261,6 +272,7 @@ void ms_load_plugins(const char *dir){
 			if (initroutine!=NULL){
 				initroutine();
 				ms_message("Plugin loaded.");
+				num++;
 			}else{
 				ms_warning("Could not locate init routine of plugin %s", szPluginFile);
 			}
@@ -292,7 +304,7 @@ void ms_load_plugins(const char *dir){
 	ds=opendir(dir);	
 	if (ds==NULL){
 		ms_message("Cannot open directory %s: %s",dir,strerror(errno));
-		return;
+		return -1;
 	}
 	while( (de=readdir(ds))!=NULL){
 		if (de->d_type==DT_REG && strstr(de->d_name,PLUGINS_EXT)!=NULL){
@@ -314,6 +326,7 @@ void ms_load_plugins(const char *dir){
 					init_func_t func=(init_func_t)initroutine;
 					func();
 					ms_message("Plugin loaded.");
+					num++;
 				}else{
 					ms_warning("Could not locate init routine of plugin %s",de->d_name);
 				}
@@ -325,7 +338,9 @@ void ms_load_plugins(const char *dir){
 	closedir(ds);
 #else
 	ms_warning("no loadable plugin support: plugins cannot be loaded.");
+	num=-1;
 #endif
+	return num;
 }
 
 
@@ -372,9 +387,12 @@ void ms_init(){
 	int i;
 	MSSndCardManager *cm;
 
+#if !defined(_WIN32_WCE)
 	if (getenv("MEDIASTREAMER_DEBUG")!=NULL){
 		ortp_set_log_level_mask(ORTP_DEBUG|ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
 	}
+#endif
+
 	/* register builtin MSFilter's */
 	for (i=0;ms_filter_descs[i]!=NULL;i++){
 		ms_filter_register(ms_filter_descs[i]);
