@@ -57,21 +57,21 @@ static void player_init(MSFilter *f){
 }
 
 static int read_wav_header(PlayerData *d){
-	char header[sizeof(wave_header_t)];
-	wave_header_t *wav=(wave_header_t*)header;
-	if (read(d->fd,header,sizeof(header))!=sizeof(header)){
+	wave_header_t wav;
+	if (read(d->fd,&wav,sizeof(wav))!=sizeof(wav)){
 		ms_warning("Could not read wav header");
 		return -1;
 	}
-	if (0!=strncmp(wav->riff_chunk.riff, "RIFF", 4) || 0!=strncmp(wav->riff_chunk.wave, "WAVE", 4)){	
+	if (0!=strncmp(wav.riff_chunk.riff, "RIFF", 4) || 0!=strncmp(wav.riff_chunk.wave, "WAVE", 4)){
 		ms_warning("Wrong wav header: (default rate/channel -> %i:%i)", d->rate, d->nchannels);
 		return -1;
 	}
-	d->rate=wave_header_get_rate(wav);
-	d->nchannels=wave_header_get_channel(wav);
-	d->hsize=sizeof(header);
+	d->rate=wave_header_get_rate(&wav);
+	d->nchannels=wave_header_get_channel(&wav);
+	d->hsize=sizeof(wav);
 #ifdef WORDS_BIGENDIAN
-	d->swap=TRUE;
+	if (wave_header_get_bpsmpl(&wav)==wave_header_get_channel(&wav) * 2)
+                d->swap=TRUE;
 #endif
 	return 0;
 }
@@ -184,6 +184,15 @@ static int player_loop(MSFilter *f, void *arg){
 	return 0;
 }
 
+static int player_eof(MSFilter *f, void *arg){
+	PlayerData *d=(PlayerData*)f->data;
+	if (d->fd<0 && d->state==CLOSED)
+		*((int*)arg) = TRUE; /* 1 */
+	else
+		*((int*)arg) = FALSE; /* 0 */
+	return 0;
+}
+
 static int player_get_nch(MSFilter *f, void *arg){
 	PlayerData *d=(PlayerData*)f->data;
 	*((int*)arg)=d->nchannels;
@@ -198,6 +207,7 @@ static MSFilterMethod player_methods[]={
 	{	MS_FILTER_GET_SAMPLE_RATE, player_get_sr},
 	{	MS_FILTER_GET_NCHANNELS, player_get_nch	},
 	{	MS_FILE_PLAYER_LOOP,	player_loop	},
+	{	MS_FILE_PLAYER_DONE,	player_eof	},
 	{	0,			NULL		}
 };
 
