@@ -159,7 +159,11 @@ static void player_process(MSFilter *f){
 					d->pause_time=d->loop_after;
 			}
 		}else{
+#if !defined(_WIN32_WCE)
 			ms_warning("Fail to read %i bytes: %s",bytes,strerror(errno));
+#else
+			ms_warning("Fail to read %i bytes: %i",bytes,WSAGetLastError());
+#endif
 		}
 	}
 }
@@ -176,6 +180,15 @@ static int player_loop(MSFilter *f, void *arg){
 	return 0;
 }
 
+static int player_eof(MSFilter *f, void *arg){
+	PlayerData *d=(PlayerData*)f->data;
+	if (d->fd==NULL && d->state==CLOSED)
+		*((int*)arg) = TRUE; /* 1 */
+	else
+		*((int*)arg) = FALSE; /* 0 */
+	return 0;
+}
+
 static int player_get_nch(MSFilter *f, void *arg){
 	PlayerData *d=(PlayerData*)f->data;
 	*((int*)arg)=d->nchannels;
@@ -190,6 +203,7 @@ static MSFilterMethod player_methods[]={
 	{	MS_FILTER_GET_SAMPLE_RATE, player_get_sr},
 	{	MS_FILTER_GET_NCHANNELS, player_get_nch	},
 	{	MS_FILE_PLAYER_LOOP,	player_loop	},
+	{	MS_FILE_PLAYER_DONE,	player_eof	},
 	{	0,			NULL		}
 };
 
