@@ -129,11 +129,23 @@ static uint32_t get_cur_timestamp(MSFilter * f, uint32_t packet_ts)
 	netts = packet_ts + d->tsoff;
 	diff = curts - netts;
 
+#ifdef AMD_HACK
+	if (diff > delta) {
+		d->tsoff = curts - packet_ts;
+		netts = packet_ts + d->tsoff;
+		ms_message("synchronizing timestamp, diff=%i", diff);
+	}
+	else if (diff < -delta) {
+		/* d->tsoff = curts - packet_ts; */
+		/* hardware clock is going slower than sound card on my PDA... */
+	}
+#else
 	if ((diff > delta) || (diff < -(delta * 5))) {
 		d->tsoff = curts - packet_ts;
 		netts = packet_ts + d->tsoff;
 		ms_message("synchronizing timestamp, diff=%i", diff);
 	}
+#endif
 
 	/*ms_message("returned ts=%u, orig_ts=%u",netts,packet_ts); */
 	return netts;
