@@ -23,6 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
 void * ms_ticker_run(void *s);
+static uint64_t get_cur_time(void *);
 
 void ms_ticker_start(MSTicker *s){
 	s->run=TRUE;
@@ -40,6 +41,8 @@ void ms_ticker_init(MSTicker *ticker)
 	ticker->interval=10;
 	ticker->run=FALSE;
 	ticker->exec_id=0;
+	ticker->get_cur_time_ptr=&get_cur_time;
+	ticker->get_cur_time_data=NULL;
 	ms_ticker_start(ticker);
 }
 
@@ -134,8 +137,7 @@ int ms_ticker_attach(MSTicker *ticker,MSFilter *f)
 
 
 
-int ms_ticker_detach(MSTicker *ticker,MSFilter *f)
-{	
+int ms_ticker_detach(MSTicker *ticker,MSFilter *f){
 	MSList *sources=NULL;
 	MSList *filters=NULL;
 	MSList *it;
@@ -253,24 +255,24 @@ static void run_graphs(MSTicker *s, MSList *execution_list, bool_t force_schedul
   };
 #endif
 
-static uint64_t get_cur_time(){
+static uint64_t get_cur_time(void *unused){
 #if defined(_WIN32_WCE)
 	DWORD timemillis = GetTickCount();
 	return timemillis;
 #else
 	struct timespec ts;
 #if defined(WIN32)
-    struct _timeb time_val;
-
-    _ftime (&time_val);
-    ts.tv_sec = time_val.time;
-    ts.tv_nsec = time_val.millitm * 1000000;
+	struct _timeb time_val;
+	
+	_ftime (&time_val);
+	ts.tv_sec = time_val.time;
+	ts.tv_nsec = time_val.millitm * 1000000;
 #elif __MACH__
-    struct timeb time_val;
-
-    ftime (&time_val);
-    ts.tv_sec = time_val.time;
-    ts.tv_nsec = time_val.millitm * 1000000;
+	struct timeb time_val;
+	
+	ftime (&time_val);
+	ts.tv_sec = time_val.time;
+	ts.tv_nsec = time_val.millitm * 1000000;
 #else
 	if (clock_gettime(CLOCK_REALTIME,&ts)<0){
 		ms_fatal("clock_gettime() doesn't work: %s",strerror(errno));
@@ -282,7 +284,7 @@ static uint64_t get_cur_time(){
 
 static void sleepMs(int ms){
 #ifdef WIN32
-    Sleep(ms);
+	Sleep(ms);
 #else
 	struct timespec ts;
 	ts.tv_sec=0;
@@ -295,20 +297,21 @@ void * ms_ticker_run(void *arg)
 {
 	MSTicker *s=(MSTicker*)arg;
 	uint64_t realtime;
-	uint64_t orig=get_cur_time();
 	int lastlate=0;
+
 	s->ticks=1;
 	ms_mutex_lock(&s->lock);
+	s->orig=s->get_cur_time_ptr(s->get_cur_time_data);
+
 	while(s->run){
 		s->ticks++;
 		run_graphs(s,s->execution_list,FALSE);
-		ms_mutex_unlock(&s->lock);
 		s->time+=s->interval;
 		while(1){
 			int64_t diff;
-			realtime=get_cur_time()-orig;
+			realtime=s->get_cur_time_ptr(s->get_cur_time_data)-s->orig;
+			ms_mutex_unlock(&s->lock);
 			diff=s->time-realtime;
-			//ms_error("Waiting %i miliseconds.",diff);
 			if (diff>0){
 				/* sleep until next tick */
 				sleepMs(diff);
@@ -320,11 +323,25 @@ void * ms_ticker_run(void *arg)
 				lastlate=late;
 				break; /*exit the while loop */
 			}
+			ms_mutex_lock(&s->lock);
 		}
 		ms_mutex_lock(&s->lock);
 	}
 	ms_cond_signal(&s->cond);
 	ms_mutex_unlock(&s->lock);
 	ms_thread_exit(NULL);
-    return NULL;
+	return NULL;
 }
+
+void ms_ticker_set_time_func(MSTicker *ticker, MSTickerTimeFunc func, void *user_data){
+	if (func==NULL) func=get_cur_time;
+	/*ms_mutex_lock(&ticker->lock);*/
+	ticker->get_cur_time_ptr=func;
+	ticker->get_cur_time_data=user_data;
+	/*re-set the origin to take in account that previous function ptr and the
+	new one may return different times*/
+	ticker->orig=func(user_data)-ticker->time;
+	/*ms_mutex_unlock(&ticker->lock);*/
+	ms_message("ms_ticker_set_time_func: ticker updated.\n");
+}
+
