@@ -17,6 +17,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#include "mediastreamer-config.h"
+
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -25,7 +27,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <errno.h>
 #include <string.h>
 #include <sys/mman.h>
+
 #include <linux/videodev.h>
+#ifdef HAVE_LINUX_VIDEODEV2_H
+#include <linux/videodev2.h>
+#endif
 
 #include "mediastreamer2/msvideo.h"
 #include "mediastreamer2/msticker.h"
@@ -52,15 +58,186 @@ typedef struct V4lState{
 	int frame_count;
 	bool_t run;
 	bool_t usemire;
+	bool_t v4lv2; /*we interface with a V4Lv2 driver */
 }V4lState;
 
 static void *v4l_thread(void *s);
 static int v4l_configure(V4lState *s);
 
+#ifdef HAVE_LINUX_VIDEODEV2_H
+
+static bool_t v4lv2_try_format(V4lState *s, int fmtid){
+	struct v4l2_format fmt;
+
+	memset(&fmt,0,sizeof(fmt));
+
+	fmt.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	fmt.fmt.pix.width       = s->vsize.width; 
+	fmt.fmt.pix.height      = s->vsize.height;
+	fmt.fmt.pix.pixelformat = fmtid;
+	/*fmt.fmt.pix.field       = V4L2_FIELD_INTERLACED;*/
+
+        if (ioctl (s->fd, VIDIOC_S_FMT, &fmt)<0){
+		return FALSE;
+	}
+	return TRUE;
+}
+
+static int v4lv2_configure(V4lState *s)
+{
+	struct v4l2_capability cap;
+	struct v4l2_cropcap cropcap;
+	struct v4l2_crop crop;
+	
+        if (ioctl (s->fd, VIDIOC_QUERYCAP, &cap)<0) {
+		ms_message("Not a v4lv2 driver.");
+		return -1;
+        }
+
+        if (!(cap.capabilities & V4L2_CAP_VIDEO_CAPTURE)) {
+		ms_error("%s is not a video capture device\n",s->dev);
+		return -1;
+        }
+
+	if (!(cap.capabilities & V4L2_CAP_STREAMING)) {
+		ms_error("%s does not support streaming i/o\n",s->dev);
+		return -1;
+	}
+
+	cropcap.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	
+	ioctl(s->fd, VIDIOC_CROPCAP, &cropcap);
+
+	crop.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	crop.c = cropcap.defrect; /* reset to default */
+	
+	ioctl(s->fd, VIDIOC_S_CROP, &crop);
+	
+	if (v4lv2_try_format(s,V4L2_PIX_FMT_YUV420)){
+		s->pix_fmt=MS_YUV420P;
+		ms_message("v4lv2: YUV420P choosen");
+	}else if (v4lv2_try_format(s,V4L2_PIX_FMT_RGB24)){
+		s->pix_fmt=MS_RGB24;
+		ms_message("v4lv2: RGB24 choosen");
+	}else if (v4lv2_try_format(s,V4L2_PIX_FMT_MJPEG)){
+		s->pix_fmt=MS_MJPEG;
+		ms_message("v4lv2: MJPEG choosen");
+	}else{
+		ms_error("Could not find supported pixel format.");
+		return -1;
+	}
+	return 0;
+}
+
+static int v4lv2_do_mmap(V4lState *s){
+	struct v4l2_requestbuffers req;
+	int i;
+	enum v4l2_buf_type type;
+	
+	memset(&req,0,sizeof(req));
+	
+	req.count               = 4;
+	req.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	req.memory              = V4L2_MEMORY_MMAP;
+	
+	if (ioctl (s->fd, VIDIOC_REQBUFS, &req)<0) {
+		ms_error("Error requesting info on mmap'd buffers: %s",strerror(errno));
+		return -1;
+	}
+	
+	for (i=0; i<req.count; ++i) {
+		struct v4l2_buffer buf;
+		mblk_t *msg;
+		void *start;
+		memset(&buf,0,sizeof(buf));
+	
+		buf.type=V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		buf.memory=V4L2_MEMORY_MMAP;
+		buf.index=i;
+	
+		if (ioctl (s->fd, VIDIOC_QUERYBUF, &buf)<0){
+			ms_error("Could not VIDIOC_QUERYBUF : %s",strerror(errno));
+			return -1;
+		}
+		
+		start=mmap (NULL /* start anywhere */,
+			buf.length,
+			PROT_READ | PROT_WRITE /* required */,
+			MAP_SHARED /* recommended */,
+			s->fd, buf.m.offset);
+	
+		if (start==NULL){
+			ms_error("Could not mmap: %s",strerror(errno));
+		}
+		msg=esballoc(start,buf.length,0,NULL);
+		msg->b_wptr+=buf.length;
+		s->frames[i]=msg;
+	}
+	s->frame_max=req.count;
+	for (i = 0; i < s->frame_max; ++i) {
+		struct v4l2_buffer buf;
+
+		memset(&buf,0,sizeof(buf));
+		buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		buf.memory      = V4L2_MEMORY_MMAP;
+		buf.index       = i;
+		if (-1==ioctl (s->fd, VIDIOC_QBUF, &buf)){
+			ms_error("VIDIOC_QBUF failed: %s",strerror(errno));
+		}
+	}
+	/*start capture immediately*/
+	type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	if (-1 ==ioctl (s->fd, VIDIOC_STREAMON, &type)){
+		ms_error("VIDIOC_STREAMON failed: %s",strerror(errno));
+		return -1;
+	}
+	return 0;
+}
+
+static mblk_t * v4lv2_grab_image(V4lState *s){
+	struct v4l2_buffer buf;
+	unsigned int i,k;
+	memset(&buf,0,sizeof(buf));
+
+	buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+	buf.memory = V4L2_MEMORY_MMAP;
+
+	if (ioctl(s->fd, VIDIOC_DQBUF, &buf)<0) {
+		switch (errno) {
+		case EAGAIN:
+			return 0;
+		case EIO:
+			/* Could ignore EIO, see spec. */
+		default:
+			ms_warning("VIDIOC_DQBUF failed: %s",strerror(errno));
+		}
+	}
+
+	if (buf.index >= s->frame_max){
+		ms_error("buf.index>=s->max_frames !");
+		return NULL;
+	}
+
+	i=buf.index;
+	/*queue buffers whose ref count has dropped to 1, because they are not
+	still used anywhere in the filter chain */
+	for(k=0;k<s->frame_max;++k){
+		if (k!=i && s->frames[k]->b_datap->db_ref==1){
+			buf.index=k;
+			if (-1==ioctl (s->fd, VIDIOC_QBUF, &buf))
+				ms_warning("VIDIOC_QBUF failed: %s",strerror(errno));
+		}
+	}
+	return s->frames[i];
+}
+
+#endif
+
 static void v4l_init(MSFilter *f){
 	V4lState *s=ms_new0(V4lState,1);
 	s->fd=-1;
 	s->run=FALSE;
+	s->v4lv2=FALSE;
 	s->mmapdbuf=NULL;
 	s->vsize.width=MS_VIDEO_SIZE_CIF_W;
 	s->vsize.height=MS_VIDEO_SIZE_CIF_H;
@@ -106,7 +283,7 @@ static int v4l_start(MSFilter *f, void *arg)
 		}
 	}
 	if (s->fd==-1){
-		s->fd=open(s->dev,O_RDONLY);
+		s->fd=open(s->dev,O_RDWR);
 		ms_message("v4l_start: open, fd=%i",s->fd);
 		if (s->fd>=0){
 			v4l_fd=s->fd;
@@ -117,14 +294,24 @@ static int v4l_start(MSFilter *f, void *arg)
 		ms_error("MSV4l: cannot open video device (%s): %s.",s->dev,strerror(errno));
 		return -1;
 	}else{
-		err=v4l_configure(s);
-		if (err<0) 
+#ifdef HAVE_LINUX_VIDEODEV2_H
+		if (v4lv2_configure(s)<0)/*might not be V4Lv2*/
+#endif
 		{
-			ms_error("MSV4l: could not get configuration of video device");
-			close(s->fd);
-			s->fd=-1;
-			return -1;
+			err=v4l_configure(s);
+			if (err<0) 
+			{
+				ms_error("MSV4l: could not get configuration of video device");
+				close(s->fd);
+				s->fd=-1;
+				return -1;
+			}
 		}
+#ifdef HAVE_LINUX_VIDEODEV2_H
+		else{
+			s->v4lv2=TRUE;
+		}
+#endif
 	}
 	return 0;
 }
@@ -309,6 +496,7 @@ static int v4l_configure(V4lState *s)
 	return 0;
 }	
 
+
 #define BPP 3
 static inline
 void crop( unsigned char *src, int s_width, int s_height, unsigned char *dest, int d_width, int d_height)
@@ -333,20 +521,6 @@ int ms_to_v4l_pix_fmt(MSPixFmt p){
 	}
 }
 
-static void v4l_purge(V4lState *s){
-	int i;
-	int err;
-	int jitter=s->frame_max-1;
-	for (i=s->frame_ind-jitter;i<s->frame_ind;++i){
-		int syncframe=i%s->frame_max;
-		ms_message("syncing last frame");
-		err=ioctl(s->fd,VIDIOCSYNC,&syncframe);
-		if (err<0) {
-			ms_warning("v4l_mmap_process: error in VIDIOCSYNC: %s.",strerror(errno));	
-		}
-	}
-}
-
 static mblk_t * v4l_grab_image_mmap(V4lState *s){
 	struct video_mmap vmap;
 	int err;
@@ -363,7 +537,8 @@ static mblk_t * v4l_grab_image_mmap(V4lState *s){
 	vmap.frame=query_frame;
 	err=ioctl(s->fd,VIDIOCMCAPTURE,&vmap);
 	if (err<0) {
-		ms_warning("v4l_mmap_process: error in VIDIOCMCAPTURE: %s.",strerror(errno));
+		ms_warning("v4l_grab_image_mmap: error in VIDIOCMCAPTURE: %s.",strerror(errno));
+		usleep(10000);
 		return NULL;
 	}
 	/*g_message("v4l_mmap_process: query_frame=%i done",
@@ -375,7 +550,7 @@ static mblk_t * v4l_grab_image_mmap(V4lState *s){
 		/*ms_message("Syncing on frame %i",syncframe);*/
 		err=ioctl(s->fd,VIDIOCSYNC,&syncframe);
 		if (err<0) {
-			ms_warning("v4l_mmap_process: error in VIDIOCSYNC: %s.",strerror(errno));	
+			ms_warning("v4l_grab_image_mmap: error in VIDIOCSYNC: %s.",strerror(errno));	
 			return NULL;
 		}
 		/*g_message("got frame %i",syncframe);*/
@@ -457,38 +632,87 @@ static mblk_t * v4l_make_nowebcam(V4lState *s){
 	return s->mire;
 }
 
+static void v4l_purge(V4lState *s){
+	int i;
+	int err;
+	int jitter=s->frame_max-1;
+	for (i=s->frame_ind-jitter;i<s->frame_ind;++i){
+		int syncframe=i%s->frame_max;
+		ms_message("syncing last frame");
+		err=ioctl(s->fd,VIDIOCSYNC,&syncframe);
+		if (err<0) {
+			ms_warning("v4l_mmap_process: error in VIDIOCSYNC: %s.",strerror(errno));	
+		}
+	}
+}
+
+
+
 static void v4l_do_munmap(V4lState *s){
 	int i;
+#ifdef HAVE_LINUX_VIDEODEV2_H
+	enum v4l2_buf_type type;
+	if (s->v4lv2){
+
+		/*stop capture immediately*/
+		type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		if (-1 ==ioctl (s->fd, VIDIOC_STREAMOFF, &type)){
+			ms_error("VIDIOC_STREAMOFF failed: %s",strerror(errno));
+		}
+	}
+#endif
+	if (!s->v4lv2){
+		v4l_purge(s);
+	}
 	if (s->mmapdbuf!=NULL){
 		if (munmap(s->mmapdbuf,s->msize)<0){
 			ms_warning("MSV4l: Fail to unmap: %s",strerror(errno));
 		}
 		ms_message("munmap() done (%p,%i)",s->mmapdbuf,s->msize);
 		s->mmapdbuf=NULL;
-		s->msize=0;
-		for(i=0;i<s->frame_max;++i){
-			freemsg(s->frames[i]);
-			s->frames[i]=NULL;
+	}
+	s->msize=0;
+	for(i=0;i<s->frame_max;++i){
+		if (s->v4lv2){
+			mblk_t *msg=s->frames[i];
+			int len=msg->b_datap->db_lim-msg->b_datap->db_base;
+			if (munmap(msg->b_datap->db_base,len)<0){
+				ms_warning("MSV4l: Fail to unmap: %s",strerror(errno));
+			}
 		}
+		freemsg(s->frames[i]);
+		s->frames[i]=NULL;
 	}
 }
 
 static void *v4l_thread(void *ptr){
 	V4lState *s=(V4lState*)ptr;
+	int err=-1;
 	ms_message("v4l_thread starting");
-	if (v4l_do_mmap(s)<0){
+	if (s->v4lv2){
+#ifdef HAVE_LINUX_VIDEODEV2_H
+		err=v4lv2_do_mmap(s);
+#endif
+	}else{
+		err=v4l_do_mmap(s);
+	}
+	if (err<0){
 		ms_thread_exit(NULL);
 	}
 	while(s->run){
 		mblk_t *m;
-		m=v4l_grab_image_mmap(s);
+#ifdef HAVE_LINUX_VIDEODEV2_H
+		if (s->v4lv2)
+			m=v4lv2_grab_image(s);
+		else
+#endif
+			m=v4l_grab_image_mmap(s);
 		if (m) {
 			ms_mutex_lock(&s->mutex);
 			putq(&s->rq,dupmsg(m));
 			ms_mutex_unlock(&s->mutex);
 		}
 	}
-	v4l_purge(s);
 	v4l_do_munmap(s);
 	ms_message("v4l_thread exited.");
 	ms_thread_exit(NULL);
@@ -526,6 +750,7 @@ static void v4l_process(MSFilter * obj){
 		if (om!=NULL){
 			timestamp=obj->ticker->time*90;/* rtp uses a 90000 Hz clockrate for video*/
 			mblk_set_timestamp_info(om,timestamp);
+			mblk_set_marker_info(om,TRUE);
 			ms_queue_put(obj->outputs[0],om);
 			/*ms_message("picture sent");*/
 		}
