@@ -185,6 +185,22 @@ static void speex_ec_process(MSFilter *f){
 	
 }
 
+static int speex_ec_set_sr(MSFilter *f, void *arg){
+#ifdef SPEEX_ECHO_SET_SAMPLING_RATE
+	SpeexECState *s=(SpeexECState*)f->data;
+	spx_int32_t tmp = *(int*)arg;
+	speex_echo_ctl(s->ecstate, SPEEX_ECHO_SET_SAMPLING_RATE, &tmp);
+#else
+	ms_error("Speex echocanceler does not support 16Khz sampling rate in this version!");
+#endif
+	return 0;
+}
+
+static MSFilterMethod speex_ec_methods[]={
+	{	MS_FILTER_SET_SAMPLE_RATE, speex_ec_set_sr },
+	{	0			, NULL}
+};
+
 #ifdef _MSC_VER
 
 MSFilterDesc ms_speex_ec_desc={
@@ -200,7 +216,7 @@ MSFilterDesc ms_speex_ec_desc={
 	speex_ec_process,
 	NULL,
 	speex_ec_uninit,
-	NULL
+	speex_ec_methods
 };
 
 #else
@@ -214,7 +230,8 @@ MSFilterDesc ms_speex_ec_desc={
 	.noutputs=2,
 	.init=speex_ec_init,
 	.process=speex_ec_process,
-	.uninit=speex_ec_uninit
+	.uninit=speex_ec_uninit,
+	.methods=speex_ec_methods
 };
 
 #endif
