@@ -27,10 +27,9 @@ typedef struct EncState{
 	theora_state tstate;
 	theora_info tinfo;
 	yuv_buffer yuv;
-	mblk_t *header;
-	mblk_t *comment;
-	mblk_t *tables;
-	uint frame_count;
+	mblk_t *packed_conf;
+	uint start_time;
+	uint conf_time;
 	uint mtu;
 } EncState;
 
@@ -52,6 +51,7 @@ static void enc_init(MSFilter *f){
 	s->tinfo.colorspace=OC_CS_UNSPECIFIED;
 	s->tinfo.dropframes_p=0;
 	s->tinfo.quick_p=1;
+	s->tinfo.quality=63;
 	s->tinfo.keyframe_auto_p=1;
 	s->tinfo.keyframe_frequency=64;
 	s->tinfo.keyframe_frequency_force=64;
@@ -59,9 +59,9 @@ static void enc_init(MSFilter *f){
 	s->tinfo.keyframe_auto_threshold=80;
 	s->tinfo.keyframe_mindistance=8;
 	s->tinfo.noise_sensitivity=1;
-	s->header=NULL;
-	s->tables=NULL;
-	s->comment=NULL;
+	s->packed_conf=NULL;
+	s->start_time=0;
+	s->conf_time=0;
 	s->mtu=1400;
 	f->data=s;
 }
@@ -100,7 +100,7 @@ static int enc_set_fps(MSFilter *f, void *data){
 	EncState *s=(EncState*)f->data;
 	s->tinfo.fps_numerator=*fps;
 	s->tinfo.keyframe_frequency=(*fps)*5;
-	s->tinfo.keyframe_frequency_force=(*fps)*5;
+	s->tinfo.keyframe_frequency_force=(*fps)*20;
 	return 0;
 }
 
@@ -114,19 +114,26 @@ static int enc_get_fps(MSFilter *f, void *data){
 static int enc_set_br(MSFilter *f, void*data){
 	int br=*(int*)data;
 	EncState *s=(EncState*)f->data;
+	MSVideoSize vsize;
+	float fps;
+	vsize.width=s->tinfo.width;
+	vsize.height=s->tinfo.height;
+	fps=s->tinfo.fps_numerator;
 	s->tinfo.target_bitrate=(float)br/1.2;
 	s->tinfo.keyframe_data_target_bitrate=br;
-	if (br<=64000){
-		MSVideoSize vsize=MS_VIDEO_SIZE_QCIF;
-		float fps=8;
-		enc_set_vsize(f,&vsize);
-		enc_set_fps(f,&fps);
-	}else if(br<=128000){
-		MSVideoSize vsize=MS_VIDEO_SIZE_CIF;
-		float fps=8;
-		enc_set_vsize(f,&vsize);
-		enc_set_fps(f,&fps);
+	/*those default settings would need to affined*/
+	if (br>=256000){
+		vsize=MS_VIDEO_SIZE_CIF;
+		fps=15;
+	}else if(br>=128000){
+		vsize=MS_VIDEO_SIZE_QCIF;
+		fps=12;
+	}else if(br>=64000){
+		vsize=MS_VIDEO_SIZE_QCIF;
+		fps=6;
 	}
+	enc_set_vsize(f,&vsize);
+	enc_set_fps(f,&fps);
 	return 0;
 }
 
@@ -137,13 +144,19 @@ static int enc_set_mtu(MSFilter *f, void*data){
 }
 
 #define THEORA_RAW_DATA	0
-#define THEORA_HEADER_DATA 1
-#define THEORA_COMMENT_DATA 2
-#define THEORA_TABLES_DATA 3
+#define THEORA_PACKED_CONF 1
+#define THEORA_COMMENT 2
+#define THEORA_RESERVED 3
 
-static inline void payload_header_set(uint8_t *buf, uint32_t ident, uint8_t tdt){
+#define NOT_FRAGMENTED 0
+#define START_FRAGMENT 1
+#define CONT_FRAGMENT 2
+#define END_FRAGMENT 3
+
+
+static inline void payload_header_set(uint8_t *buf, uint32_t ident, uint8_t ft, uint8_t tdt, uint8_t pkts){
 	uint32_t tmp;
-	tmp=((ident&0xFFFFFF)<<8)| (tdt&0xff);
+	tmp=((ident&0xFFFFFF)<<8) | ((ft&0x3)<<6) | ((tdt&0x3)<<4) | (pkts&0xf);
 	*((uint32_t*)buf)=htonl(tmp);
 }
 
@@ -154,15 +167,23 @@ static inline uint32_t payload_header_get_ident(uint8_t *buf){
 
 static inline uint32_t payload_header_get_tdt(uint8_t *buf){
 	uint32_t *tmp=(uint32_t*)buf;
-	return (ntohl(*tmp)) & 0xFF;
+	return ((ntohl(*tmp))>>4) & 0x3;
 }
 
+static inline uint32_t payload_header_get_ft(uint8_t *buf){
+	uint32_t *tmp=(uint32_t*)buf;
+	return ((ntohl(*tmp))>>6) & 0x3;
+}
+
+static inline uint32_t payload_header_get_pkts(uint8_t *buf){
+	uint32_t *tmp=(uint32_t*)buf;
+	return ntohl(*tmp) & 0xf;
+}
 
 static int create_packed_conf(EncState *s){
 	ogg_packet p;
 	theora_state *tstate=&s->tstate;
-	mblk_t *h,*t,*c;
-	theora_comment tcom;
+	mblk_t *h,*t;
 	if (theora_encode_header(tstate,&p)!=0){
 		ms_error("theora_encode_header() error.");
 		return -1;
@@ -178,19 +199,9 @@ static int create_packed_conf(EncState *s){
 	t=allocb(p.bytes,0);
 	memcpy(t->b_wptr,p.packet,p.bytes);
 	t->b_wptr+=p.bytes;
-	theora_comment_init(&tcom);
-	if (tcom.vendor==NULL) tcom.vendor="Xiph";
-	if (theora_encode_comment(&tcom,&p)!=0){
-		ms_error("theora_encode_tables error.");
-		freemsg(h);
-		freemsg(t);
-		return -1;
-	}
-	s->header=h;
-	s->tables=t;
-	s->comment=c=allocb(p.bytes,0);
-	memcpy(c->b_wptr,p.packet,p.bytes);
-	c->b_wptr+=p.bytes;
+	h->b_cont=t;
+	msgpullup(h,-1);
+	s->packed_conf=h;
 	return 0;
 }
 
@@ -206,16 +217,18 @@ static void enc_preprocess(MSFilter *f){
 	s->yuv.uv_height=s->tinfo.height/2;
 	s->yuv.uv_stride=s->tinfo.width/2;
 	create_packed_conf(s);
-	s->frame_count=0;
+	s->conf_time=0;
+	s->start_time=f->ticker->time;
 }
 
 static void enc_postprocess(MSFilter *f){
 	EncState *s=(EncState*)f->data;
 	theora_clear(&s->tstate);
 	theora_info_clear(&s->tinfo);
-	if (s->header) freemsg(s->header);
-	if (s->tables) freemsg(s->tables);
-	if (s->comment) freemsg(s->comment);
+	if (s->packed_conf) {
+		freemsg(s->packed_conf);
+		s->packed_conf=NULL;
+	}
 }
 
 static void enc_fill_yuv(yuv_buffer *yuv, mblk_t *im){
@@ -228,7 +241,8 @@ static void enc_fill_yuv(yuv_buffer *yuv, mblk_t *im){
 static void packetize_and_send(MSFilter *f, EncState *s, mblk_t *om, uint32_t timestamp, uint8_t tdt){
 	mblk_t *packet;
 	mblk_t *h;
-	bool_t markbit=FALSE;
+	int npackets=0;
+	static const int ident=0xdede;
 	while(om!=NULL){
 		if (om->b_wptr-om->b_rptr>=s->mtu){
 			packet=dupb(om);
@@ -237,14 +251,25 @@ static void packetize_and_send(MSFilter *f, EncState *s, mblk_t *om, uint32_t ti
 		}else {
 			packet=om;
 			om=NULL;
-			markbit=TRUE;
 		}
-		h=allocb(4,0);
-		payload_header_set((uint8_t*)h->b_wptr,0xdede,tdt);
+		++npackets;
+		h=allocb(6,0);
+		if (npackets==1){
+			if (om==NULL)
+				payload_header_set(h->b_wptr,ident,NOT_FRAGMENTED,tdt,1);
+			else
+				payload_header_set(h->b_wptr,ident,START_FRAGMENT,tdt,1);
+		}else{
+			if (om==NULL)
+				payload_header_set(h->b_wptr,ident,END_FRAGMENT,tdt,1);
+			else
+				payload_header_set(h->b_wptr,ident,CONT_FRAGMENT,tdt,1);
+		}
 		h->b_wptr+=4;
+		*((uint16_t*)h->b_wptr)=htons(msgdsize(packet));
+		h->b_wptr+=2;
 		h->b_cont=packet;
 		mblk_set_timestamp_info(h,timestamp);
-		mblk_set_marker_info(h,markbit);
 		ms_debug("sending theora frame of size %i",msgdsize(h));
 		ms_queue_put(f->outputs[0],h);
 	}
@@ -256,17 +281,17 @@ static void enc_process(MSFilter *f){
 	EncState *s=(EncState*)f->data;
 	uint timems=f->ticker->time;
 	uint32_t timestamp=timems*90;
+	int elapsed=timems-s->start_time;
 	while((im=ms_queue_get(f->inputs[0]))!=NULL){
 		/*for the firsts frames only send theora packed conf*/
 		om=NULL;
-		if (s->frame_count<16){
-			if (s->frame_count%5==0){
-				om=dupmsg(s->header);
-				ms_debug("sending theora header");
-				packetize_and_send(f,s,om,timestamp,THEORA_HEADER_DATA);
-				om=dupmsg(s->tables);
-				ms_debug("sending theora tables");
-				packetize_and_send(f,s,om,timestamp,THEORA_TABLES_DATA);
+		if (elapsed<1000){
+			/* during the first second, only send packed conf twice */
+			if (elapsed>=s->conf_time){
+				s->conf_time+=500;
+				om=dupmsg(s->packed_conf);
+				ms_debug("sending theora packed conf");
+				packetize_and_send(f,s,om,timestamp,THEORA_PACKED_CONF);
 			}
 		}else{
 			enc_fill_yuv(&s->yuv,im);
@@ -283,7 +308,6 @@ static void enc_process(MSFilter *f){
 				}
 			}
 		}
-		s->frame_count++;
 		freemsg(im);
 	}
 }
@@ -304,7 +328,7 @@ MSFilterDesc ms_theora_enc_desc={
 	.name="MSTheoraEnc",
 	.text="The theora video encoder from xiph.org",
 	.category=MS_FILTER_ENCODER,
-	.enc_fmt="x-theora",
+	.enc_fmt="theora",
 	.ninputs=1,
 	.noutputs=1,
 	.init=enc_init,
@@ -322,16 +346,12 @@ typedef struct DecState{
 	theora_info tinfo;
 	mblk_t *yuv;
 	mblk_t *curframe;
-	bool_t header_recv;
-	bool_t tables_recv;
 	bool_t ready;
 }DecState;
 
 static void dec_init(MSFilter *f){
 	DecState *s=ms_new(DecState,1);
 	s->ready=FALSE;
-	s->header_recv=FALSE;
-	s->tables_recv=FALSE;
 	theora_info_init(&s->tinfo);
 	s->yuv=NULL;
 	s->curframe=NULL;
@@ -346,55 +366,59 @@ static void dec_uninit(MSFilter *f){
 	ms_free(s);
 }
 
-static bool_t dec_init_theora(DecState *s, ogg_packet *op, int tdt){
-	int err;
+static bool_t dec_init_theora(DecState *s, ogg_packet *op){
 	theora_comment tcom;
 	theora_comment_init(&tcom);
 	tcom.vendor="dummy";
 	op->b_o_s=1;
-	err=theora_decode_header(&s->tinfo,&tcom,op);
-	if (err==0){
-		switch(tdt){
-			case THEORA_HEADER_DATA:
-				ms_debug("Theora header decoded");
-				s->header_recv=TRUE;
-				break;
-			case THEORA_COMMENT_DATA:
-				ms_debug("Theora comment decoded");
-				break;
-			case THEORA_TABLES_DATA:
-				ms_debug("Theora tables decoded");
-				s->tables_recv=TRUE;
-				break;
-			default:
-				ms_error("bad theora payload header");
-		}
-		if (s->header_recv && s->tables_recv){
+	static const int ident_packet_size=42; 
+	if (theora_decode_header(&s->tinfo,&tcom,op)==0){
+		op->packet+=ident_packet_size;
+		op->bytes-=ident_packet_size;
+		/*recall once to decode tables*/
+		if (theora_decode_header(&s->tinfo,&tcom,op)==0){
 			if (theora_decode_init(&s->tstate,&s->tinfo)==0){
 				ms_debug("theora decoder ready, pixfmt=%i",
 					s->tinfo.pixelformat);
 				return TRUE;	
 			}
+		}else{
+			ms_warning("error decoding theora tables");
 		}
 	}else{
-		ms_warning("error decoding theora header of type %i",tdt);
+		ms_warning("error decoding theora header");
 	}
 	return FALSE;
 }
 /* remove payload header and agregates fragmented packets */
 static mblk_t *dec_unpacketize(MSFilter *f, DecState *s, mblk_t *im, int *tdt){
-	mblk_t *ret=NULL;
+	uint8_t ft;
 	*tdt=payload_header_get_tdt((uint8_t*)im->b_rptr);
-	im->b_rptr+=4;
-	if (s->curframe!=NULL){
-		concatb(s->curframe,im);
-	}else s->curframe=im;
-	if (mblk_get_marker_info(im)) {
-		ret=s->curframe;
-		msgpullup(ret,-1);
-		s->curframe=NULL;
+	ft=payload_header_get_ft((uint8_t*)im->b_rptr);
+	im->b_rptr+=6;
+	
+	if (ft==NOT_FRAGMENTED)	return im;
+	if (ft==START_FRAGMENT){
+		if (s->curframe!=NULL)
+			freemsg(s->curframe);
+		s->curframe=im;
+	}else if (ft==CONT_FRAGMENT){
+		if (s->curframe!=NULL)
+			concatb(s->curframe,im);
+		else
+			freemsg(im);
+	}else{/*end fragment*/
+		if (s->curframe!=NULL){
+			mblk_t *ret;
+			concatb(s->curframe,im);
+			msgpullup(s->curframe,-1);
+			ret=s->curframe;
+			s->curframe=NULL;
+			return ret;
+		}else
+			freemsg(im);
 	}
-	return ret;
+	return NULL;
 }
 
 static void dec_process_frame(MSFilter *f, DecState *s, ogg_packet *op){
@@ -448,7 +472,7 @@ static void dec_process(MSFilter *f){
 			op.packetno=0;
 			if (tdt!=THEORA_RAW_DATA) /*packed conf*/ {
 				if (!s->ready){
-					if (dec_init_theora(s,&op,tdt))
+					if (dec_init_theora(s,&op))
 						s->ready=TRUE;
 				}
 			}else{
@@ -468,7 +492,7 @@ MSFilterDesc ms_theora_dec_desc={
 	.name="MSTheoraDec",
 	.text="The theora video decoder from xiph.org",
 	.category=MS_FILTER_DECODER,
-	.enc_fmt="x-theora",
+	.enc_fmt="theora",
 	.ninputs=1,
 	.noutputs=1,
 	.init=dec_init,
