@@ -50,6 +50,7 @@ typedef struct EncState{
 	int profile;
 	float fps;
 	int maxbr;
+	int qmin;
 }EncState;
 
 static int enc_set_fps(MSFilter *f, void *arg){
@@ -85,18 +86,25 @@ static int enc_set_mtu(MSFilter *f,void *arg){
 static int enc_set_br(MSFilter *f, void *arg){
 	EncState *s=(EncState*)f->data;
 	s->maxbr=*(int*)arg;
-	if (s->maxbr<=128000){
-		/* this setting limits to 64kbit/s*/
-		s->vsize=MS_VIDEO_SIZE_QCIF;
-		s->fps=3;
-	}else if (s->maxbr<=256000){
-		/* this setting limits to 128kbit/s*/
-		s->vsize=MS_VIDEO_SIZE_QCIF;
-		s->fps=7;
-	}else if (s->maxbr<=512000){
-		/* this setting limits to 128kbit/s*/
-		s->vsize=MS_VIDEO_SIZE_CIF;
-		s->fps=7;
+	if (s->maxbr>=512000){
+		s->vsize.width=MS_VIDEO_SIZE_CIF_W;
+		s->vsize.height=MS_VIDEO_SIZE_CIF_H;
+		s->fps=17;
+	}else if (s->maxbr>=256000){
+		s->vsize.width=MS_VIDEO_SIZE_CIF_W;
+		s->vsize.height=MS_VIDEO_SIZE_CIF_H;
+		s->fps=10;
+		s->qmin=3;
+	}else if (s->maxbr>=128000){
+		s->vsize.width=MS_VIDEO_SIZE_QCIF_W;
+		s->vsize.height=MS_VIDEO_SIZE_QCIF_H;
+		s->fps=10;
+		s->qmin=3;
+	}else if (s->maxbr>=64000){
+		s->vsize.width=MS_VIDEO_SIZE_QCIF_W;
+		s->vsize.height=MS_VIDEO_SIZE_QCIF_H;
+		s->fps=5;
+		s->qmin=4;
 	}
 	return 0;
 }
@@ -142,11 +150,7 @@ static int enc_add_fmtp(MSFilter *f,void *arg){
 	const char *fmtp=(const char*)arg;
 	char val[10];
 	if (fmtp_get_value(fmtp,"profile",val,sizeof(val))){
-		if (atoi(val)==0){
-			/*if profile=0, use simple H263 */
-			ms_message("not using H263P encoder because profile is 0");
-			s->profile=0;
-		}
+		s->profile=atoi(val);
 	}else parse_video_fmtp(fmtp,&s->fps,&s->vsize);
 	return 0;
 }
@@ -156,7 +160,7 @@ static void enc_init(MSFilter *f, enum CodecID codec)
 	EncState *s=ms_new(EncState,1);
 	f->data=s;
 	ms_ffmpeg_check_init();
-	s->profile=-1;
+	s->profile=0;/*always default to profile 0*/
 	s->comp_buf=allocb(32000,0);
 	s->fps=15;
 	s->mtu=1400;
@@ -164,6 +168,7 @@ static void enc_init(MSFilter *f, enum CodecID codec)
 	s->codec=codec;
 	s->vsize.width=MS_VIDEO_SIZE_CIF_W;
 	s->vsize.height=MS_VIDEO_SIZE_CIF_H;
+	s->qmin=2;
 }
 
 static void enc_h263_init(MSFilter *f){
@@ -186,6 +191,7 @@ static void prepare(EncState *s){
 	c->time_base.den = 1;
 	c->gop_size=(int)s->fps*5; /*emit I frame every 5 seconds*/
 	c->pix_fmt=PIX_FMT_YUV420P;
+	c->qmin=s->qmin;
 }
 
 static void prepare_h263(EncState *s){
@@ -233,7 +239,7 @@ static void enc_preprocess(MSFilter *f){
 	EncState *s=(EncState*)f->data;
 	int error;
 	prepare(s);
-	if (s->codec==CODEC_ID_H263P)
+	if (s->codec==CODEC_ID_H263P || s->codec==CODEC_ID_H263)
 		prepare_h263(s);
 	else if (s->codec==CODEC_ID_MPEG4)
 		prepare_mpeg4(s);
@@ -252,6 +258,7 @@ static void enc_preprocess(MSFilter *f){
 		return;
 	}
 	ms_debug("image format is %i.",s->av_context.pix_fmt);
+	ms_message("qmin=%i qmax=%i",s->av_context.qmin,s->av_context.qmax);
 }
 
 static void enc_postprocess(MSFilter *f){
