@@ -21,12 +21,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define DISABLE_SPEEX
 #endif
 
+#ifndef MAX_WAVEHDR
+#define MAX_WAVEHDR 6
+#endif
+
 #ifndef DISABLE_SPEEX
 #include <speex/speex_preprocess.h>
 #endif
 
 #include "mediastreamer2/mssndcard.h"
 #include "mediastreamer2/msfilter.h"
+#include "mediastreamer2/msticker.h"
 
 #ifdef WIN32
 #include <malloc.h> /* for alloca */
@@ -69,8 +74,18 @@ typedef struct WinSndData{
 #ifndef DISABLE_SPEEX
 	SpeexPreprocessState *pst;
 #endif
+
+	uint64_t bytes_read;
 } WinSndData;
 
+static uint64_t winsnd_get_cur_time( void *data){
+	WinSndData *d=(WinSndData*)data;
+	uint64_t curtime=(d->bytes_read*1000)/(d->rate*(d->bits/8)*((d->stereo==FALSE) ? 1 : 2));
+	ms_debug("winsnd_get_cur_time: bytes_read=%lu, rate=%i, bits=%i, stereo=%i return %lu\n",
+	(unsigned long)d->bytes_read,d->rate,d->bits,d->stereo,(unsigned long)curtime);
+	return curtime;
+}
+
 static void CALLBACK
 SpeakerCallback (HWAVEOUT _waveoutdev, UINT uMsg, DWORD dwInstance,
                  DWORD dwParam1, DWORD dwParam2)
@@ -143,8 +158,7 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
             }
             return;
         }
-
-
+	device->bytes_read+=wHdr->dwBytesRecorded;
     	ms_mutex_lock(&device->mutex);
 		if (device->read_started)
         {
@@ -167,7 +181,6 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
 
 #endif
 			rm->b_wptr+=wHdr->dwBufferLength;
-		    
 			putq(&device->rq,rm);
 		    rm=NULL;
         }
@@ -221,7 +234,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
     /* prepare windows buffers */
 
 
-    for (i = 0; i < 6; i++)
+    for (i = 0; i < MAX_WAVEHDR; i++)
     {
         memset (&(device->waveouthdr[i]), 0, sizeof (device->waveouthdr[i]));
         device->waveouthdr[i].lpData = device->waveoutbuffer[i];
@@ -267,7 +280,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
 
 
 
-    for (i = 0; i < 6; i++)
+    for (i = 0; i < MAX_WAVEHDR; i++)
     {
         memset (&(device->waveinhdr[i]), 0, sizeof (device->waveinhdr[i]));
         device->waveinhdr[i].lpData = device->waveinbuffer[i];
@@ -317,7 +330,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
 	}
 #endif
 #endif
-
+	device->bytes_read=0;
 	mr = waveInStart (device->waveindev);
     if (mr != MMSYSERR_NOERROR)
     {
@@ -446,6 +459,7 @@ static void winsnd_uninit(MSSndCard *card){
 #define MIXER_NAME "/dev/mixer"
 
 static void winsnd_detect(MSSndCardManager *m);
+static  MSSndCard *winsnd_dup(MSSndCard *obj);
 
 MSSndCardDesc winsnd_card_desc={
 	"WINSND",
@@ -456,9 +470,20 @@ MSSndCardDesc winsnd_card_desc={
 	winsnd_set_source,
 	ms_winsnd_read_new,
 	ms_winsnd_write_new,
-	winsnd_uninit
+	winsnd_uninit,
+	winsnd_dup
 };
 
+static  MSSndCard *winsnd_dup(MSSndCard *obj){
+	MSSndCard *card=ms_snd_card_new(&winsnd_card_desc);
+	WinSndData *dcard=(WinSndData*)card->data;
+	WinSndData *dobj=(WinSndData*)obj->data;
+	dcard->pcmdev=ms_strdup(dobj->pcmdev);
+	dcard->mixdev=ms_strdup(dobj->mixdev);
+	card->name=ms_strdup(obj->name);
+	return card;
+}
+
 static MSSndCard *winsnd_card_new(const char *pcmdev, const char *mixdev){
 	MSSndCard *card=ms_snd_card_new(&winsnd_card_desc);
 	WinSndData *d=(WinSndData*)card->data;
@@ -554,7 +579,7 @@ static void * winsnd_thread(void *p){
 #endif
 			if (d->write_started){
 
-                if (d->buffer_playing<4)
+                if (d->buffer_playing<4 && d->buffer_playing<MAX_WAVEHDR)
                 {
 					/* remove extra buffer when latency is increasing:
 					this often happen with USB device */
@@ -594,7 +619,7 @@ static void * winsnd_thread(void *p){
                         {
                             d->buffer_playing++;
                             pos_whdr++;
-                            if (pos_whdr == 6)
+                            if (pos_whdr == MAX_WAVEHDR)
                                 pos_whdr = 0;   /* loop over the prepared blocks */
                         }
 
@@ -627,7 +652,7 @@ static void * winsnd_thread(void *p){
                     Sleep(10);
                 }
 			}else {
-                if (d->buffer_playing<3)
+                if (d->buffer_playing<3 && d->buffer_playing<MAX_WAVEHDR)
                 {
 				    memset(wtmpbuff,0,bsize);
     				
@@ -655,7 +680,7 @@ static void * winsnd_thread(void *p){
                     {
                         d->buffer_playing++;
                         pos_whdr++;
-                        if (pos_whdr == 6)
+                        if (pos_whdr == MAX_WAVEHDR)
                             pos_whdr = 0;   /* loop over the prepared blocks */
                     }
 			    }
@@ -672,7 +697,7 @@ static void * winsnd_thread(void *p){
         /* close sound card */
 
         /* unprepare buffer */
-        for (i = 0; i < 6; i++)
+        for (i = 0; i < MAX_WAVEHDR; i++)
         {
             int counttry=0;
             for (counttry=0;counttry<10;counttry++)
@@ -683,7 +708,7 @@ static void * winsnd_thread(void *p){
                 if (mr != MMSYSERR_NOERROR)
                 {
                     ms_error("Failed to unprepared %i buffer from sound card (waveInUnprepareHeader:0x%i", count, mr);
-                    Sleep (200);
+                    Sleep (20);
                 } else
                 {
                     count++;
@@ -779,10 +804,12 @@ static void winsnd_put(MSSndCard *card, mblk_t *m){
 static void winsnd_read_preprocess(MSFilter *f){
 	MSSndCard *card=(MSSndCard*)f->data;
 	winsnd_start_r(card);
+	ms_ticker_set_time_func(f->ticker,winsnd_get_cur_time,card->data);
 }
 
 static void winsnd_read_postprocess(MSFilter *f){
 	MSSndCard *card=(MSSndCard*)f->data;
+	ms_ticker_set_time_func(f->ticker,NULL,NULL);
 	winsnd_stop_r(card);
 }
 
@@ -826,6 +853,7 @@ static int set_nchannels(MSFilter *f, void *arg){
 	return 0;
 }
 
+
 static MSFilterMethod winsnd_methods[]={
 	{	MS_FILTER_SET_SAMPLE_RATE	, set_rate	},
 	{	MS_FILTER_SET_NCHANNELS		, set_nchannels	},
