@@ -18,16 +18,33 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
-#include "msfilter.h"
-#include "mssndcard.h"
-#include "msticker.h"
+#include "mediastreamer2/msfilter.h"
+#include "mediastreamer2/mssndcard.h"
+#include "mediastreamer2/msticker.h"
 
-int main(){
+#include <signal.h>
+
+static int run=1;
+
+static void stop(int signum){
+	run=0;
+}
+
+int main(int argc, char *argv[]){
 	MSFilter *f1,*f2;
 	MSSndCard *card;
 	MSTicker *ticker;
+	char *card_id=NULL;
 	ms_init();
-	card=ms_snd_card_manager_get_card(ms_snd_card_manager_get(),0);
+	
+	signal(SIGINT,stop);
+
+	if (argc>1)
+		card_id=argv[1];
+
+	if (card_id!=NULL)
+		card=ms_snd_card_manager_get_card(ms_snd_card_manager_get(),card_id);
+	else card=ms_snd_card_manager_get_default_card(ms_snd_card_manager_get());
 	if (card==NULL){
 		ms_error("No card.");
 		return -1;
@@ -37,7 +54,8 @@ int main(){
 	ticker=ms_ticker_new();
 	ms_filter_link(f1,0,f2,0);
 	ms_ticker_attach(ticker,f1);
-	sleep(5);
+	while(run)
+		sleep(1);
 	ms_ticker_detach(ticker,f1);
 	ms_ticker_destroy(ticker);
 	ms_filter_unlink(f1,0,f2,0);
