@@ -18,28 +18,26 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "mediastreamer-config.h"
 #endif
 
-#include "mediastream.h"
+#include "mediastreamer2/mediastream.h"
 
 int main(int argc, char *argv[]){
 	RingStream *r;
 	const char *file;
 	MSSndCard *sc;
-	int card_index=0;
+	const char * card_id=NULL;
 	ms_init();
 	if (argc>1){
 		file=argv[1];
-	}else file=PACKAGE_SOUND_DIR "/rings/oldphone.wav";
+	}else file="/usr/share/sounds/linphone/rings/oldphone.wav";
 	if (argc>2){
-		card_index=atoi(argv[2]);
+		card_id=argv[2];
 	}
-	sc=ms_snd_card_manager_get_card(ms_snd_card_manager_get(),card_index);
+	sc=ms_snd_card_manager_get_card(ms_snd_card_manager_get(),card_id);
 	r=ring_start(file,2000,sc);
 	sleep(10);
 	ring_stop(r);
 	return 0;
 }
-
-
