@@ -59,7 +59,7 @@ extern unsigned int __ortp_log_mask;
 
 #define ortp_log_level_enabled(level)	(__ortp_log_mask & (level))
 
-#ifndef WIN32
+#if !defined(WIN32) && !defined(_WIN32_WCE)
 #define ortp_logv(level,fmt,args) \
 {\
 	if (ortp_logv_out!=NULL && ortp_log_level_enabled(level)) \
@@ -88,7 +88,7 @@ static inline void ortp_debug(const char *fmt,...)
   va_end (args);
 }
 #else
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
 static inline void ortp_debug(const char *fmt,...)
 {
   va_list args;
