@@ -28,6 +28,7 @@
 #include <ortp/rtcp.h>
 #include <ortp/str_utils.h>
 #include <ortp/rtpsignaltable.h>
+#include <ortp/event.h>
 
 
 
@@ -38,19 +39,6 @@ typedef enum {
 } RtpSessionMode;
 
 
-
-typedef enum {
-	RTP_SESSION_RECV_SYNC=1,	/* the rtp session is synchronising in the incoming stream */
-	RTP_SESSION_SEND_SYNC=1<<1, /* the rtp session is synchronising in the outgoing stream */
-	RTP_SESSION_SCHEDULED=1<<2, /* the rtp session has to be scheduled */
-	RTP_SESSION_BLOCKING_MODE=1<<3, /* in blocking mode */
-	RTP_SESSION_RECV_NOT_STARTED=1<<4,	/* the application has not started to try to recv */
-	RTP_SESSION_SEND_NOT_STARTED=1<<5,  /* the application has not started to send something */
-	RTP_SESSION_IN_SCHEDULER=1<<6,	/* the rtp session is in the scheduler list */
-	RTP_SESSION_USING_EXT_SOCKETS=1<<7 /* the session is using externaly supplied sockets */
-}RtpSessionFlags;
-
-
 typedef struct _JitterControl
 {
 	int jitt_comp;   /* the user jitt_comp in miliseconds*/
@@ -101,7 +89,6 @@ typedef struct _RtpStream
 	uint32_t rcv_query_ts_offset;	/* the first user timestamp asked by the application */
 	uint32_t rcv_diff_ts;	/* difference between the first user timestamp and first stream timestamp */
 	uint32_t hwrcv_diff_ts;
-	uint32_t rcv_ts;			/* to be unused */
 	uint32_t rcv_last_ts;	/* the last stream timestamp got by the application */
 	uint32_t rcv_last_app_ts; /* the last application timestamp asked by the application */	
 	uint32_t rcv_last_ret_ts; /* the timestamp of the last sample returned (only for continuous audio)*/
@@ -114,6 +101,11 @@ typedef struct _RtpStream
 	uint32_t last_rtcp_report_snt_r;	/* the time of the last rtcp report sent, in recv timestamp unit */
 	uint32_t last_rtcp_report_snt_s;	/* the time of the last rtcp report sent, in send timestamp unit */
 	uint32_t rtcp_report_snt_interval; /* the interval in timestamp unit between rtcp report sent */
+	uint32_t last_rtcp_packet_count; /*the sender's octet count in the last sent RTCP SR*/
+	unsigned int sent_bytes; /* used for bandwidth estimation */
+	struct timeval send_bw_start; /* used for bandwidth estimation */
+	unsigned int recv_bytes; /* used for bandwidth estimation */
+	struct timeval recv_bw_start; /* used for bandwidth estimation */
 	rtp_stats_t stats;
 }RtpStream;
 
@@ -141,7 +133,6 @@ struct _RtpSession
 	RtpProfile *profile;
 	WaitPoint recv_wp;
 	WaitPoint send_wp;
-	ortp_mutex_t lock;
 	uint32_t send_ssrc;
 	uint32_t recv_ssrc;
 	int send_pt;/* sent payload type */
@@ -156,11 +147,15 @@ struct _RtpSession
 	RtpSignalTable on_network_error;
 	RtpSignalTable on_rtcp_bye;
 	struct _OList *signal_tables;
+	struct _OList *eventqs;
 	RtpStream rtp;
 	RtcpStream rtcp;
 	RtpSessionMode mode;
 	struct _RtpScheduler *sched;
 	uint32_t flags;
+	int dscp;
+	int multicast_ttl;
+	int multicast_loopback;
 	void * user_data;
 	/* FIXME: Should be a table for all session participants. */
 	struct timeval last_recv_time; /* Time of receiving the RTP/RTCP packet. */
@@ -170,7 +165,9 @@ struct _RtpSession
 	mblk_t *current_tev;		/* the pending telephony events */
 	mblk_t *sd;
 	queue_t contributing_sources;
-	int symmetric_rtp;
+	bool_t symmetric_rtp;
+	bool_t permissive; /*use the permissive algorithm*/
+	bool_t use_connect; /* use connect() on the socket */
 };
 	
 
@@ -183,8 +180,6 @@ extern "C"
 
 /*private */
 void rtp_session_init(RtpSession *session, int mode);
-#define rtp_session_lock(session) 	ortp_mutex_lock(&(session)->lock)
-#define rtp_session_unlock(session) ortp_mutex_unlock(&(session)->lock)
 #define rtp_session_set_flag(session,flag) (session)->flags|=(flag)
 #define rtp_session_unset_flag(session,flag) (session)->flags&=~(flag)
 void rtp_session_uninit(RtpSession *session);
@@ -195,8 +190,8 @@ void rtp_session_set_scheduling_mode(RtpSession *session, int yesno);
 void rtp_session_set_blocking_mode(RtpSession *session, int yesno);
 void rtp_session_set_profile(RtpSession *session,RtpProfile *profile);
 RtpProfile *rtp_session_get_profile(RtpSession *session);
-int rtp_session_signal_connect(RtpSession *session,const char *signal, RtpCallback cb, unsigned long user_data);
-int rtp_session_signal_disconnect_by_callback(RtpSession *session,const char *signal, RtpCallback cb);
+int rtp_session_signal_connect(RtpSession *session,const char *signal_name, RtpCallback cb, unsigned long user_data);
+int rtp_session_signal_disconnect_by_callback(RtpSession *session,const char *signal_name, RtpCallback cb);
 void rtp_session_set_ssrc(RtpSession *session, uint32_t ssrc);
 void rtp_session_set_seq_number(RtpSession *session, uint16_t seq);
 uint16_t rtp_session_get_seq_number(RtpSession *session);
@@ -211,6 +206,25 @@ int rtp_session_set_remote_addr(RtpSession *session,const char *addr, int port);
 a valid socket (potentially connect()ed )to be used by the RtpSession */
 void rtp_session_set_sockets(RtpSession *session, int rtpfd, int rtcpfd);
 
+/*those methods are provided for people who wants to send non-RTP messages using the RTP/RTCP sockets */
+ortp_socket_t rtp_session_get_rtp_socket(const RtpSession *session);
+ortp_socket_t rtp_session_get_rtcp_socket(const RtpSession *session);
+
+
+/* QOS / DSCP */
+int rtp_session_set_dscp(RtpSession *session, int dscp);
+int rtp_session_get_dscp(const RtpSession *session);
+
+
+/* Multicast methods */
+int rtp_session_set_multicast_ttl(RtpSession *session, int ttl);
+int rtp_session_get_multicast_ttl(RtpSession *session);
+
+int rtp_session_set_multicast_loopback(RtpSession *session, int yesno);
+int rtp_session_get_multicast_loopback(RtpSession *session);
+
+
+
 int rtp_session_set_send_payload_type(RtpSession *session, int paytype);
 int rtp_session_get_send_payload_type(const RtpSession *session);
 
@@ -219,32 +233,42 @@ int rtp_session_set_recv_payload_type(RtpSession *session, int pt);
 
 int rtp_session_set_payload_type(RtpSession *session, int pt);
 
-/* deprecated API:
-int rtp_session_set_payload_type(RtpSession *session, int paytype);
-int rtp_session_get_payload_type(RtpSession *session);
-int rtp_session_set_payload_type_with_string (RtpSession * session, const char * mime);
-*/
+void rtp_session_set_symmetric_rtp (RtpSession * session, bool_t yesno);
+
+void rtp_session_set_connected_mode(RtpSession *session, bool_t yesno);
 
 /*low level recv and send functions */
 mblk_t * rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts);
-mblk_t * rtp_session_create_packet(RtpSession *session,int header_size, const char *payload, int payload_size);
-mblk_t * rtp_session_create_packet_with_data(RtpSession *session, char *payload, int payload_size, void (*freefn)(void*));
-mblk_t * rtp_session_create_packet_in_place(RtpSession *session,char *buffer, int size, void (*freefn)(void*) );
+mblk_t * rtp_session_create_packet(RtpSession *session,int header_size, const uint8_t *payload, int payload_size);
+mblk_t * rtp_session_create_packet_with_data(RtpSession *session, uint8_t *payload, int payload_size, void (*freefn)(void*));
+mblk_t * rtp_session_create_packet_in_place(RtpSession *session,uint8_t *buffer, int size, void (*freefn)(void*) );
 int rtp_session_sendm_with_ts (RtpSession * session, mblk_t *mp, uint32_t userts);
 /* high level recv and send functions */
-int rtp_session_recv_with_ts(RtpSession *session, char *buffer, int len, uint32_t time, int *have_more);
-int rtp_session_send_with_ts(RtpSession *session, const char *buffer, int len, uint32_t userts);
+int rtp_session_recv_with_ts(RtpSession *session, uint8_t *buffer, int len, uint32_t ts, int *have_more);
+int rtp_session_send_with_ts(RtpSession *session, const uint8_t *buffer, int len, uint32_t userts);
 
+/* event API*/
+void rtp_session_register_event_queue(RtpSession *session, OrtpEvQueue *q);
+void rtp_session_unregister_event_queue(RtpSession *session, OrtpEvQueue *q);
+
+
+/* IP bandwidth usage estimation functions, returning bits/s*/
+float rtp_session_compute_send_bandwidth(RtpSession *session);
+float rtp_session_compute_recv_bandwidth(RtpSession *session);
+
+void rtp_session_send_rtcp_APP(RtpSession *session, uint8_t subtype, const char *name, const uint8_t *data, int datalen);
 
 uint32_t rtp_session_get_current_send_ts(RtpSession *session);
 uint32_t rtp_session_get_current_recv_ts(RtpSession *session);
 void rtp_session_flush_sockets(RtpSession *session);
 void rtp_session_release_sockets(RtpSession *session);
+void rtp_session_resync(RtpSession *session);
 void rtp_session_reset(RtpSession *session);
 void rtp_session_destroy(RtpSession *session);
 
-#define rtp_session_get_stats(session) (&(session)->stats)
-#define rtp_session_reset_stats(session)	memset(&(session)->stats,0,sizeof(rtp_stats_t))
+const rtp_stats_t * rtp_session_get_stats(const RtpSession *session);
+void rtp_session_reset_stats(RtpSession *session);
+
 void rtp_session_set_data(RtpSession *session, void *data);
 void *rtp_session_get_data(const RtpSession *session);
 
@@ -252,7 +276,7 @@ void rtp_session_set_recv_buf_size(RtpSession *session, int bufsize);
 
 /* in use with the scheduler to convert a timestamp in scheduler time unit (ms) */
 uint32_t rtp_session_ts_to_time(RtpSession *session,uint32_t timestamp);
-uint32_t rtp_session_time_to_ts(RtpSession *session, int time);
+uint32_t rtp_session_time_to_ts(RtpSession *session, int millisecs);
 /* this function aims at simulating senders with "imprecise" clocks, resulting in 
 rtp packets sent with timestamp uncorrelated with the system clock .
 This is only availlable to sessions working with the oRTP scheduler */
@@ -271,17 +295,7 @@ mblk_t* rtp_session_create_rtcp_sdes_packet(RtpSession *session);
 void rtp_session_get_last_recv_time(RtpSession *session, struct timeval *tv);
 int rtp_session_bye(RtpSession *session, const char *reason);
 
-/* packet api */
-/* the first argument is a mblk_t. The header is supposed to be not splitted  */
-#define rtp_set_markbit(mp,value)		((rtp_header_t*)((mp)->b_rptr))->markbit=(value)
-#define rtp_set_seqnumber(mp,seq)	((rtp_header_t*)((mp)->b_rptr))->seq_number=(seq)
-#define rtp_set_timestamp(mp,ts)	((rtp_header_t*)((mp)->b_rptr))->timestamp=(ts)
-#define rtp_set_ssrc(mp,_ssrc)		((rtp_header_t*)((mp)->b_rptr))->ssrc=(_ssrc)
-void rtp_add_csrc(mblk_t *mp,uint32_t csrc);
-#define rtp_set_payload_type(mp,pt)	((rtp_header_t*)((mp)->b_rptr))->paytype=(pt)
 
-#define rtp_get_timestamp(mp)	(((rtp_header_t*)((mp)->b_rptr))->timestamp)	
-#define rtp_get_markbit(mp)	(((rtp_header_t*)((mp)->b_rptr))->markbit)	
 
 #ifdef __cplusplus
 }
