@@ -68,6 +68,13 @@ void jitter_control_dump_stats(JitterControl *ctl){
 }
 
 
+void jitter_control_update_corrective_slide(JitterControl *ctl){
+	int tmp;
+	tmp=(int)(ctl->slide)-ctl->corrective_slide;
+	if (tmp>ctl->corrective_step) ctl->corrective_slide+=ctl->corrective_step;
+	else if (tmp<-ctl->corrective_step) ctl->corrective_slide-=ctl->corrective_step;
+}
+
 /*
  The algorithm computes two values:
 	slide: an average of difference between the expected and the socket-received timestamp
@@ -90,13 +97,9 @@ void jitter_control_new_packet(JitterControl *ctl, uint32_t packet_ts, uint32_t
 	ctl->inter_jitter=(float) (ctl->inter_jitter+ (( (float)abs(d) - ctl->inter_jitter)*(1/16.0)));
 	ctl->olddiff=diff;
 	if (ctl->adaptive){
-		int tmp;
 		if (ctl->count%50==0) {
 			/*jitter_control_dump_stats(ctl);*/
 		}
-		tmp=(int)(ctl->slide)-ctl->corrective_slide;
-		if (tmp>ctl->corrective_step) ctl->corrective_slide+=ctl->corrective_step;
-		else if (tmp<-ctl->corrective_step) ctl->corrective_slide-=ctl->corrective_step;
 		/* the following is nearly equivalent, but maybe it consumes more CPU: ?*/
 		/*ctl->corrective_slide=(((int)ctl->slide)/ctl->corrective_step)*ctl->corrective_step;*/
 		
@@ -123,14 +126,11 @@ void jitter_control_new_packet(JitterControl *ctl, uint32_t packet_ts, uint32_t
 void
 rtp_session_set_jitter_compensation (RtpSession * session, int milisec)
 {
-	PayloadType *payload;
-	if (session->recv_pt==-1) return; /* not set */
-	payload = rtp_profile_get_payload (session->profile,session->recv_pt);
+	PayloadType *payload=NULL;
+	if (session->recv_pt!=-1) {
+		payload = rtp_profile_get_payload (session->profile,session->recv_pt);
+	}/*else not set yet */
 	jitter_control_init(&session->rtp.jittctl,milisec,payload);
-	if (payload==NULL){
-		ortp_warning("rtp_session_set_jitter_compensation: cannot set because the payload type (%i) is unknown",session->recv_pt);
-		return;
-	}
 }
 
 void rtp_session_enable_adaptive_jitter_compensation(RtpSession *session, bool_t val){
