@@ -19,9 +19,12 @@
 
 
 /* ortp-config-win32.h.  Generated manually...  */
-
-/* tell if we have glib installed somewhere */
-#define HAVE_GLIB 1
+#define ORTP_VERSION		"0.8.2"
+#define ORTP_MAJOR_VERSION	0
+#define ORTP_MINOR_VERSION	8
+#define ORTP_MICRO_VERSION	2
+#define ORTP_EXTRA_VERSION
 
 /* define the debug mode */
 #define RTP_DEBUG 1
+
