@@ -225,7 +225,6 @@ rtp_session_init (RtpSession * session, int mode)
 	if ((mode == RTP_SESSION_SENDONLY) || (mode == RTP_SESSION_SENDRECV))
 	{
 		rtp_session_set_flag (session, RTP_SESSION_SEND_NOT_STARTED);
-		rtp_session_set_flag (session, RTP_SESSION_SEND_SYNC);
 		session->send_ssrc=uint32_t_random();
 		/* set default source description */
 		rtp_session_set_source_description(session,"unknown@unknown",NULL,NULL,
@@ -327,8 +326,7 @@ rtp_session_set_scheduling_mode (RtpSession * session, int yesno)
  *@session: a rtp session
  *@yesno: a boolean
  *
- *	Using this function implies that you previously enabled scheduled mode on the session
- *  (see rtp_session_set_scheduling_mode() ).
+ *	This function implicitely enables the scheduling mode if yesno is TRUE.
  *	rtp_session_set_blocking_mode() defines the behaviour of the rtp_session_recv_with_ts() and 
  *	rtp_session_send_with_ts() functions. If @yesno is TRUE, rtp_session_recv_with_ts()
  *	will block until it is time for the packet to be received, according to the timestamp
@@ -340,9 +338,10 @@ rtp_session_set_scheduling_mode (RtpSession * session, int yesno)
 void
 rtp_session_set_blocking_mode (RtpSession * session, int yesno)
 {
-	if (yesno)
+	if (yesno){
+		rtp_session_set_scheduling_mode(session,TRUE);
 		rtp_session_set_flag (session, RTP_SESSION_BLOCKING_MODE);
-	else
+	}else
 		rtp_session_unset_flag (session, RTP_SESSION_BLOCKING_MODE);
 }
 
@@ -868,12 +867,11 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	if (session->flags & RTP_SESSION_RECV_NOT_STARTED)
 	{
 		session->rtp.rcv_query_ts_offset = user_ts;
-        /* Set initial last_rcv_time to first recv time. */
-        if ((session->flags & RTP_SESSION_SEND_NOT_STARTED)
-            || session->mode == RTP_SESSION_RECVONLY)
-        {
-            gettimeofday(&session->last_recv_time, NULL);
-        }
+		/* Set initial last_rcv_time to first recv time. */
+		if ((session->flags & RTP_SESSION_SEND_NOT_STARTED)
+		|| session->mode == RTP_SESSION_RECVONLY){
+			gettimeofday(&session->last_recv_time, NULL);
+		}
 		if (session->flags & RTP_SESSION_SCHEDULED)
 		{
 			session->rtp.rcv_time_offset = sched->time_;
@@ -887,6 +885,9 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	/* check for telephone event first */
 	mp=getq(&session->rtp.tev_rq);
 	if (mp!=NULL){
+		int msgsize=msgdsize(mp);
+		ortp_global_stats.recv += msgsize;
+		stream->stats.recv += msgsize;
 		rtp_signal_table_emit2(&session->on_telephone_event_packet,(long)mp);
 		rtp_session_check_telephone_events(session,mp);
 		freemsg(mp);
@@ -899,43 +900,27 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	
 	if (session->flags & RTP_SESSION_RECV_SYNC)
 	{
-		rtp_header_t *oldest, *newest;
 		queue_t *q = &session->rtp.rq;
 		if (qempty(q))
 		{
 			ortp_debug ("Queue is empty.");
 			goto end;
 		}
-		oldest = (rtp_header_t *) qfirst(q)->b_rptr;
-		newest = (rtp_header_t *) qlast(q)->b_rptr;
-		if ((uint32_t) (newest->timestamp - oldest->timestamp) <
-		    (uint32_t) session->rtp.jittctl.jitt_comp_ts)
-		{
-			ortp_debug("Not enough packet bufferised.");
-			goto end;
-		}
-		/* enough packet bufferised */
-		mp = getq (&session->rtp.rq);
-		rtp = (rtp_header_t *) mp->b_rptr;
+		rtp = (rtp_header_t *) qfirst(q)->b_rptr;
 		session->rtp.rcv_ts_offset = rtp->timestamp;
 		/* remember the timestamp offset between the stream timestamp (random)
 		 * and the user timestamp, that very often starts at zero */
-		session->rtp.rcv_diff_ts = rtp->timestamp - user_ts;
+		session->rtp.hwrcv_diff_ts = rtp->timestamp - user_ts;
 		/* remember the difference between the last received on the socket timestamp and the user timestamp */
-		session->rtp.hwrcv_diff_ts=session->rtp.rcv_diff_ts + session->rtp.jittctl.jitt_comp_ts;
+		session->rtp.rcv_diff_ts=session->rtp.hwrcv_diff_ts - session->rtp.jittctl.jitt_comp_ts;
 		session->rtp.rcv_last_ret_ts = user_ts;	/* just to have an init value */
 		session->recv_ssrc = rtp->ssrc;
 		/* delete the recv synchronisation flag */
 		rtp_session_unset_flag (session, RTP_SESSION_RECV_SYNC);
-		ortp_debug("Returning FIRST packet with ts=%i, hwrcv_diff_ts=%i, rcv_diff_ts=%i", rtp->timestamp,
-					session->rtp.hwrcv_diff_ts,session->rtp.rcv_diff_ts);
-
-		goto end;
 	}
-	/* else this the normal case */
 	/*calculate the stream timestamp from the user timestamp */
 	ts = user_ts + session->rtp.rcv_diff_ts;
-	if (session->permissive)
+	if (session->permissive || session->rtp.jittctl.jitt_comp_ts==0)
 		mp = rtp_getq_permissive(&session->rtp.rq, ts,&rejected);
 	else
 		mp = rtp_getq(&session->rtp.rq, ts,&rejected);
@@ -973,6 +958,9 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 			/*printf("Returned packet has timestamp %u, with clock slide compensated it is %u\n",packet_ts,rtp->timestamp);*/
 		}
 		session->rtp.rcv_last_ts = packet_ts;
+		if (!(session->flags & RTP_SESSION_FIRST_PACKET_DELIVERED)){
+			rtp_session_set_flag(session,RTP_SESSION_FIRST_PACKET_DELIVERED);
+		}
 	}
 	else
 	{
@@ -1351,6 +1339,21 @@ void rtp_session_uninit (RtpSession * session)
 	session->signal_tables = o_list_free(session->signal_tables);
 }
 
+/**
+ * rtp_session_resync:
+ * @session: the rtp session
+ *
+ * Resynchronize to the incoming RTP streams.
+ * This can be useful to handle discoutinuous timestamps.
+ * For example, call this function from the timestamp_jump signal handler.
+**/
+void rtp_session_resync(RtpSession *session){
+	flushq (&session->rtp.rq, FLUSHALL);
+	rtp_session_set_flag(session, RTP_SESSION_RECV_SYNC);
+	rtp_session_unset_flag(session,RTP_SESSION_FIRST_PACKET_DELIVERED);
+	jitter_control_init(&session->rtp.jittctl,-1,NULL);
+}
+
 /**
  *rtp_session_reset:
  *@session: a rtp session.
@@ -1362,10 +1365,6 @@ void rtp_session_uninit (RtpSession * session)
 **/
 void rtp_session_reset (RtpSession * session)
 {
-	
-	flushq (&session->rtp.rq, FLUSHALL);
-	rtp_session_set_flag (session, RTP_SESSION_RECV_SYNC);
-	rtp_session_set_flag (session, RTP_SESSION_SEND_SYNC);
 	rtp_session_set_flag (session, RTP_SESSION_RECV_NOT_STARTED);
 	rtp_session_set_flag (session, RTP_SESSION_SEND_NOT_STARTED);
 	//session->ssrc=0;
@@ -1383,8 +1382,7 @@ void rtp_session_reset (RtpSession * session)
 	session->rtp.hwrcv_since_last_SR=0;
 	session->rtp.snd_seq = 0;
 	rtp_stats_reset(&session->rtp.stats);
-	jitter_control_init(&session->rtp.jittctl,-1,NULL);
-
+	rtp_session_resync(session);
 }
 
 const rtp_stats_t * rtp_session_get_stats(const RtpSession *session){
@@ -1418,11 +1416,37 @@ void *rtp_session_get_data(const RtpSession *session){
 	return session->user_data;
 }
 
+/**
+ *rtp_session_set_symmetric_rtp:
+ *	@session : a rtp session
+ *	@yesno : a boolean to enable or disable the feature
+ *
+ *	Enable or disable the "rtp symmetric" hack: after the first packet is
+ *	received, the source address of the packet is set to be the destination
+ *	address for all nexts packets.
+**/
 void
-rtp_session_set_symmetric_rtp (RtpSession * session, int yesno)
+rtp_session_set_symmetric_rtp (RtpSession * session, bool_t yesno)
 {
-	session->symmetric_rtp = (yesno!=0);
-	return;
+	session->symmetric_rtp =yesno;
+}
+
+/**
+ *rtp_session_set_connected_mode:
+ *	@session : a rtp session
+ *	@yesno : a boolean to enable or disable the feature
+ *
+ *	If yesno is TRUE, thus a connect() syscall is done on the socket to 
+ *	the destination address set by rtp_session_set_remote_addr(), or
+ *	if the session does symmetric rtp (see rtp_session_set_symmetric_rtp())
+ *	a the connect() is done to the source address of the first packet received.
+ *	Connecting a socket has effect of rejecting all incoming packets that 
+ *	don't come from the address specified in connect().
+ *	It also makes ICMP errors (such as connection refused) available to the
+ *	application.
+**/
+void rtp_session_set_connected_mode(RtpSession *session, bool_t yesno){
+	session->use_connect=yesno;
 }
 
 static float compute_bw(struct timeval *orig, unsigned int bytes){
