@@ -741,7 +741,9 @@ stunRand(void)
       int seed;
       init = true;
 
-#if defined(_MSC_VER)
+#if defined(_WIN32_WCE)
+      tick = GetTickCount ();
+#elif defined(_MSC_VER)
       {
       volatile unsigned int lowtick=0,hightick=0;
       __asm
@@ -758,7 +760,7 @@ stunRand(void)
       asm("rdtsc" : "=A" (tick));
 #elif defined(__GNUC__) && defined(__amd64__)
       asm("rdtsc" : "=A" (tick));
-#elif defined (__SUNPRO_CC) || defined( __sparc__ )	
+#elif defined (__SUNPRO_CC) && defined( __sparc__ )	
       tick = gethrtime();
 #elif defined(__MACH__) 
       {
@@ -803,14 +805,14 @@ stunRand(void)
 #     error Need some way to seed the random number generator 
 #endif 
       seed = (int)(tick);
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
       srand(seed);
 #else
       srandom(seed);
 #endif
    }
 	
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
    /* assert( RAND_MAX == 0x7fff ); */
    {
        int r1 = rand();
@@ -949,7 +951,7 @@ UInt64
 stunGetSystemTimeSecs(void)
 {
    UInt64 time=0;
-#if defined(WIN32)  
+#if	defined(_WIN32) || defined(_WIN32_WCE)
    SYSTEMTIME t;
    /*  CJ TODO - this probably has bug on wrap around every 24 hours */
    GetSystemTime( &t );
@@ -1013,7 +1015,7 @@ stunParseHostName( char* peerName,
 	
    /* figure out the host part */
 	
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
    /* assert( strlen(host) >= 1 ); */
    if ( isdigit( host[0] ) )
    {
@@ -1030,7 +1032,7 @@ stunParseHostName( char* peerName,
 		
       if ( h == NULL )
       {
-         int err = getErrno();
+         /*int err = getErrno();*/
 
          /* printf("error was %i\n", err); */
          /* std::cerr << "error was " << err << std::endl; */
@@ -1487,6 +1489,7 @@ stunStopServer(StunServerInfo *info)
    }
 }
 
+#if 0 /* no usefull here */
 
 bool
 stunServerProcess(StunServerInfo *info, bool verbose)
@@ -1499,7 +1502,7 @@ stunServerProcess(StunServerInfo *info, bool verbose)
    bool recvAltPort = false;
 	
    fd_set fdSet; 
-#ifdef WIN32
+#if	defined(_WIN32) || defined(_WIN32_WCE)
    unsigned int maxFd=0;
 #else
    int maxFd=0;
@@ -1586,8 +1589,14 @@ stunServerProcess(StunServerInfo *info, bool verbose)
       /* do the media relaying */
       if (info->relay)
       {
-         time_t now = time(0);
+         time_t now;
          int i;
+#if !defined(_WIN32_WCE)
+         now = time(0);
+#else
+         DWORD timemillis = GetTickCount();
+         now = timemillis/1000;
+#endif
          for (i=0; i<MAX_MEDIA_RELAYS; ++i)
          {
             StunMediaRelay* relay = &info->relays[i];
@@ -1776,11 +1785,12 @@ stunServerProcess(StunServerInfo *info, bool verbose)
    
    return true;
 }
+#endif
 
 int 
 stunFindLocalInterfaces(UInt32* addresses,int maxRet)
 {
-#if defined(WIN32) || defined(__sparc__)
+#if defined(WIN32) || defined(_WIN32_WCE) || defined(__sparc__)
    return 0;
 #else
    struct ifconf ifc;
@@ -1938,7 +1948,9 @@ stunSendTest( Socket myFd, StunAddress4 *dest,
    sendMessage( myFd, buf, len, dest->addr, dest->port, verbose );
 	
    /* add some delay so the packets don't get sent too quickly */
-#ifdef WIN32 /* !cj! TODO - should fix this up in windows */
+#if defined(_WIN32_WCE) 
+   Sleep (10);
+#elif defined(WIN32)/* !cj! TODO - should fix this up in windows */
    {
        clock_t now = clock();
        assert( CLOCKS_PER_SEC == 1000 );
@@ -2018,7 +2030,7 @@ stunTest( StunAddress4 *dest, int testNum, bool verbose, StunAddress4* sAddr , S
    if ( verbose )
    {
       printf("\t ok=%i\n", ok );
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
       printf("\t id=%u\n", *(unsigned int*)&resp.msgHdr.id );
 #endif
       printf("\t mappedAddr=%i\n", resp.mappedAddress.ipv4.addr );
@@ -2134,7 +2146,7 @@ stunNatType( StunAddress4 *dest,
       int err;
       int e;
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
       unsigned int fdSetSize;
 #else
       int fdSetSize;
