@@ -19,6 +19,7 @@
 
 #include <ortp/telephonyevents.h>
 #include "utils.h"
+#include "rtpsession_priv.h"
 #include <ortp/ortp.h>
 
 PayloadType	payload_type_telephone_event={
@@ -258,12 +259,24 @@ int rtp_session_read_telephone_event(RtpSession *session,
 	return num;
 }
 
+static void notify_tev(RtpSession *session, telephone_event_t *event){
+	OrtpEvent *ev;
+	OrtpEventData *evd;
+	rtp_signal_table_emit2(&session->on_telephone_event,(long)(long)event[0].event);
+	if (session->eventqs!=NULL){
+		ev=ortp_event_new(ORTP_EVENT_TELEPHONE_EVENT);
+		evd=ortp_event_get_data(ev);
+		evd->packet=dupmsg(session->current_tev);
+		evd->info.telephone_event=event[0].event;
+		rtp_session_dispatch_event(session,ev);
+	}
+}
 
 static void notify_events_ended(RtpSession *session, telephone_event_t *events, int num){
 	int i;
 	for (i=0;i<num;i++){
 		if (events[i].E==1){
-			rtp_signal_table_emit2(&session->on_telephone_event,(long)(long)events[i].event);
+			notify_tev(session, &events[i]);
 		}
 	}
 }
@@ -313,7 +326,7 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 					if (evbuf[i].E==0){
 						evbuf[i].E=1;
 						/* this is a end of event, report it */
-						rtp_signal_table_emit2(&session->on_telephone_event,(long)(long)events[i].event);
+						notify_tev(session,&events[i]);
 					}
 				}
 			}
